#!/usr/bin/python3
"""
This module provides functions for processing and generating labels for country names based on separators.
"""

import functools
import re
from typing import Tuple

from ...format_bots.relation_mapping import translation_category_relations
from ...helps import logger
from ...new_resolvers.bys_new import resolve_by_labels
from ...new_resolvers.reslove_all import new_resolvers_all
from ...time_resolvers.time_to_arabic import convert_time_to_arabic
from ...translations import get_from_pf_keys2
from ...utils import fix_minor
from .. import sport_lab_suffixes, team_work, with_years_bot
from ..films_and_others_bot import te_films
from ..ma_bots import country_bot
from ..make_bots.bot_2018 import get_pop_All_18
from ..matables_bots.bot import add_to_Films_O_TT
from ..matables_bots.check_bot import check_key_new_players
from ..matables_bots.table1_bot import get_KAKO
from ..o_bots import bys, parties_bot, univer
from ..o_bots.peoples_resolver import work_peoples
from .utils import split_text_by_separator


@functools.lru_cache(maxsize=10000)
def wrap_lab_for_country2(country: str) -> str:
    """
    TODO: should be moved to functions directory.
    Retrieve laboratory information for a specified country.
    """

    country2 = country.lower().strip()

    resolved_label = (
        new_resolvers_all(country2)
        or get_from_pf_keys2(country2)
        or get_pop_All_18(country2)
        or te_films(country2)
        or sport_lab_suffixes.get_teams_new(country2)
        or parties_bot.get_parties_lab(country2)
        or team_work.Get_team_work_Club(country2)
        or univer.te_universities(country2)
        or work_peoples(country2)
        or get_KAKO(country2)
        or convert_time_to_arabic(country2)
        or get_pop_All_18(country2)
        or ""
    )
    logger.info(f'>> wrap_lab_for_country2 "{country2}": label: {resolved_label}')

    return resolved_label


def time_label(text: str) -> str:
    """Generate a time-related label based on the provided text."""
    tst3 = re.sub(r"\d+", "", text.strip())
    test3_results = ["", "-", "–", "−"]
    if tst3 in test3_results:
        return text
    return ""


def get_table_with_in(cone_1: str, separator: str) -> str:
    table_with_in = {
        "sport in": "الرياضة في",
    }
    con_1_in = f"{cone_1.strip()} {separator.strip()}"
    part_1_label = table_with_in.get(con_1_in, "")
    logger.debug(f"<<<< {con_1_in=}, {part_1_label=}")

    return part_1_label


@functools.lru_cache(maxsize=10000)
def c_1_1_lab(separator: str, cone_1: str, with_years: bool = False) -> str:
    """
    Retrieve a label based on the given parameters.
    Example:
        {"separator": " in ", "cone_1": "cultural depictions of competitors", "output": "تصوير ثقافي عن منافسون"},
    """

    cone_1 = cone_1.strip().lower()

    if cone_1 == "women" and separator.strip() == "from":
        part_1_label = "نساء"
        logger.debug(f">> >> >> Make {cone_1=}.")
        return part_1_label

    part_1_label = (
        get_pop_All_18(cone_1)
        or te_films(cone_1)
        or new_resolvers_all(cone_1)
        or sport_lab_suffixes.get_teams_new(cone_1)
        or parties_bot.get_parties_lab(cone_1)
        or team_work.Get_team_work_Club(cone_1)
        or get_table_with_in(cone_1, separator)
        or convert_time_to_arabic(cone_1)
        or time_label(cone_1)
        or get_from_pf_keys2(cone_1)
        or get_KAKO(cone_1)
        or ""
    )

    if not part_1_label:
        logger.debug(f'>>>> XX--== part_1_label =  "{part_1_label}" {cone_1=}')

    return part_1_label


@functools.lru_cache(maxsize=10000)
def c_2_1_lab(cone_2: str, with_years: bool = False) -> str:
    """Retrieve a label based on the provided cone identifier."""

    cone_2 = cone_2.strip().lower()

    part_2_label = (
        get_pop_All_18(cone_2)
        or bys.get_by_label(cone_2)
        or te_films(cone_2)
        or new_resolvers_all(cone_2)
        or sport_lab_suffixes.get_teams_new(cone_2)
        or parties_bot.get_parties_lab(cone_2)
        or bys.get_and_label(cone_2)
        or team_work.Get_team_work_Club(cone_2)
        or get_from_pf_keys2(cone_2.strip().lower())
        or get_KAKO(cone_2)
        or time_label(cone_2)
        or convert_time_to_arabic(cone_2)
        or ""
    )

    logger.debug(f"{cone_2=} -> {part_2_label=}")

    return part_2_label


def _resolve_war(resolved_label: str, part_2_normalized: str, part_1_normalized: str) -> str:
    maren = re.match(r"\d\d\d\d", part_2_normalized)
    if maren:
        if part_1_normalized == "war of" and resolved_label == f"الحرب في {part_2_normalized}":
            resolved_label = f"حرب {part_2_normalized}"
            logger.info(f'<<lightpurple>> >>>> change cnt_la to "{resolved_label}".')

    return resolved_label


def make_cnt_lab(
    separator: str,
    country: str,
    part_2_label: str,
    part_1_label: str,
    part_1_normalized: str,
    part_2_normalized: str,
    ar_separator: str,
) -> str:
    """
    Construct a formatted string based on various input parameters.
    """
    country2 = country.lower().strip()

    resolved_label = part_1_label + ar_separator + part_2_label
    in_players = check_key_new_players(part_1_normalized.lower())

    if in_players:
        if in_players:
            if part_2_label.startswith("أصل "):
                logger.info(f">>>>>> Add من to {part_1_normalized=} part_1_normalized in New_players:")
                resolved_label = f"{part_1_label}{ar_separator}من {part_2_label}"
            else:
                logger.info(f">>>>>> Add في to {part_1_normalized=} part_1_normalized in New_players:")
                if not resolved_label.strip().endswith(" في"):
                    resolved_label += " في "

        if not resolve_by_labels(part_2_normalized):
            # Films_O_TT[country2] = resolved_label
            add_to_Films_O_TT(country2, resolved_label)
        else:
            logger.info("<<lightblue>>>>>> part_2_normalized in By table main")

    if part_2_label:
        label_format_mappings = {
            "politics of {}": "سياسة {}",
            "military installations of": "منشآت {} العسكرية",
        }
        if part_1_normalized in label_format_mappings:
            logger.info(
                f'<<lightblue>>>>>> part_1_normalized in label_format_mappings "{label_format_mappings[part_1_normalized]}":'
            )
            resolved_label = label_format_mappings[part_1_normalized].format(part_2_label)

    # NOTE: important to fix bug like: [sport in ottoman] = "الرياضة في في الدولة العثمانية" !

    resolved_label = resolved_label.replace(" في في ", " في ")

    logger.info(f'<<lightpurple>> >>>> country 2_tit "{country2}": label: {resolved_label}')

    resolved_label = " ".join(resolved_label.strip().split())
    resolved_label = _resolve_war(resolved_label, part_2_normalized, part_1_normalized)

    if resolved_label.endswith(" في "):
        resolved_label = resolved_label[: -len(" في ")]

    return resolved_label


def separator_arabic_resolve(separator: str) -> str:
    """
    Generate a specific string based on input parameters.
    TODO: need refactoring
    """
    ar_separator = " "
    separator = separator.strip()

    if separator == "to":
        ar_separator = " إلى "
    elif separator == "on":
        ar_separator = " على "
    elif separator == "about":
        ar_separator = " عن "
    elif separator in translation_category_relations and separator != "by":
        ar_separator = f" {translation_category_relations[separator]} "
    elif separator == "based in":
        ar_separator = " مقرها في "

    return ar_separator


# @dump_data()
def make_parts_labels(part_1, part_2, separator, with_years) -> Tuple[str, str]:
    part_2_label = (
        new_resolvers_all(part_2)
        or c_2_1_lab(part_2)
        or country_bot.Get_c_t_lab(part_2, "")
        or (with_years_bot.Try_With_Years(part_2) if with_years else "")
        or ""
    )

    part_1_label = (
        new_resolvers_all(part_1)
        or c_1_1_lab(separator, part_1, with_years=with_years)
        or country_bot.Get_c_t_lab(part_1, "", lab_type="type_label")
        or ""
    )

    if part_2_label == "" or part_1_label == "":
        logger.info(f">>>> XX--== <<lightgreen>> {part_1=}, {part_1_label=}, {part_2=}, {part_2_label=}")
        return "", ""

    part_1_normalized = part_1.strip().lower()
    part_2_normalized = part_2.strip().lower()

    if (separator.strip() == "in" or part_1_normalized.endswith(" in")) and (not part_1_normalized.endswith(" في")):
        logger.debug(f">>>> Add في to {part_1_label=}")
        part_1_label = f"{part_1_label} في"

    elif (separator.strip() == "from" or part_2_normalized.endswith(" from")) and (not part_2_label.endswith(" من")):
        logger.debug(f">>>> Add من to {part_2_label=}")
        part_2_label = f"من {part_2_label}"

    return part_1_label, part_2_label


def get_separator(country: str) -> str:
    title_separators = [
        "based in",
        "in",
        "by",
        "about",
        "to",
        "of",
        "-of ",  # special case
        "from",
        "at",
        "on",
    ]

    normalized_country = country.lower().strip()

    for sep in title_separators:
        separator = f" {sep} " if sep != "-of " else sep
        if separator in normalized_country:
            return separator

    return ""


def country_2_title_work(country: str, with_years: bool = True) -> str:
    separator = get_separator(country)

    if not separator:
        logger.info(f">>>> country_2_title_work <<red>> {separator=}")
        return ""

    part_1, part_2 = split_text_by_separator(separator, country)

    logger.info(f"2060 {part_1=}, {part_2=}, {separator=}")

    part_1_label, part_2_label = make_parts_labels(part_1, part_2, separator, with_years)

    if part_2_label == "" or part_1_label == "":
        logger.info(f">>>> XX--== <<lightgreen>> {part_1=}, {part_1_label=}, {part_2=}, {part_2_label=}")
        return ""

    part_1_normalized = part_1.strip().lower()
    part_2_normalized = part_2.strip().lower()

    logger.info(
        f">>>> XX--== <<lightgreen>> {part_1_normalized=}, {part_1_label=}, {part_2_normalized=}, {part_2_label=}"
    )

    if separator.strip() == "to" and (
        part_1_label.startswith("سفراء ") or part_1_normalized.strip() == "ambassadors of"
    ):
        ar_separator = " لدى "
    else:
        ar_separator = separator_arabic_resolve(separator)

    resolved_label = make_cnt_lab(
        separator=separator,
        country=country,
        part_2_label=part_2_label,
        part_1_label=part_1_label,
        part_1_normalized=part_1_normalized,
        part_2_normalized=part_2_normalized,
        ar_separator=ar_separator,
    )

    resolved_label = fix_minor(resolved_label, separator)

    return resolved_label


__all__ = [
    "make_cnt_lab",
    "country_2_title_work",
    "separator_arabic_resolve",
    "split_text_by_separator",
]



#
import pytest
from load_one_data import dump_diff, one_dump_test

from ArWikiCats import resolve_arabic_category_label

data_1 = {
    "Category:Deaths by American airstrikes during the Syrian civil war": "تصنيف:وفيات بضربات جوية أمريكية خلال الحرب الأهلية السورية",
    "Category:Deaths by American airstrikes during World War II": "تصنيف:وفيات بضربات جوية أمريكية خلال الحرب العالمية الثانية",
    "Category:Deaths by American airstrikes": "تصنيف:وفيات بضربات جوية أمريكية",
    "Category:Deaths by car bomb by country": "تصنيف:وفيات بسيارة مفخخة حسب البلد",
    "Category:Deaths by car bomb in Afghanistan": "تصنيف:وفيات بسيارة مفخخة في أفغانستان",
    "Category:Deaths by car bomb in England": "تصنيف:وفيات بسيارة مفخخة في إنجلترا",
    "Category:Deaths by car bomb in France": "تصنيف:وفيات بسيارة مفخخة في فرنسا",
    "Category:Deaths by car bomb in Iran": "تصنيف:وفيات بسيارة مفخخة في إيران",
    "Category:Deaths by car bomb in Iraq": "تصنيف:وفيات بسيارة مفخخة في العراق",
    "Category:Deaths by car bomb in Italy": "تصنيف:وفيات بسيارة مفخخة في إيطاليا",
    "Category:Deaths by car bomb in Lebanon": "تصنيف:وفيات بسيارة مفخخة في لبنان",
    "Category:Deaths by car bomb in Malta": "تصنيف:وفيات بسيارة مفخخة في مالطا",
    "Category:Deaths by car bomb in Northern Ireland": "تصنيف:وفيات بسيارة مفخخة في أيرلندا الشمالية",
    "Category:Deaths by car bomb in Somalia": "تصنيف:وفيات بسيارة مفخخة في الصومال",
    "Category:Deaths by car bomb in Spain": "تصنيف:وفيات بسيارة مفخخة في إسبانيا",
    "Category:Deaths by car bomb in Syria": "تصنيف:وفيات بسيارة مفخخة في سوريا",
    "Category:Deaths by car bomb in the United Kingdom": "تصنيف:وفيات بسيارة مفخخة في المملكة المتحدة",
    "Category:Deaths by car bomb in the United States": "تصنيف:وفيات بسيارة مفخخة في الولايات المتحدة",
    "Category:Deaths by car bomb in Turkey": "تصنيف:وفيات بسيارة مفخخة في تركيا",
    "Category:Deaths by car bomb in Yemen": "تصنيف:وفيات بسيارة مفخخة في اليمن",
    "Category:Deaths by century": "تصنيف:وفيات حسب القرن",
    "Category:Deaths by continent": "تصنيف:وفيات حسب القارة",
    "Category:Deaths by country subdivision": "تصنيف:وفيات حسب تقسيم البلد",
    "Category:Deaths by decade": "تصنيف:وفيات حسب العقد",
    "Category:Deaths by Egyptian airstrikes": "تصنيف:وفيات بضربات جوية مصرية",
    "Category:Deaths by firearm in Afghanistan": "تصنيف:وفيات بإطلاق النار في أفغانستان",
    "Category:Deaths by firearm in Alabama": "تصنيف:وفيات بإطلاق النار في ألاباما",
    "Category:Deaths by firearm in Alaska": "تصنيف:وفيات بإطلاق النار في ألاسكا",
    "Category:Deaths by firearm in Albania": "تصنيف:وفيات بإطلاق النار في ألبانيا",
    "Category:Deaths by firearm in Alberta": "تصنيف:وفيات بإطلاق النار في ألبرتا",
    "Category:Deaths by firearm in Angola": "تصنيف:وفيات بإطلاق النار في أنغولا",
    "Category:Deaths by firearm in Argentina": "تصنيف:وفيات بإطلاق النار في الأرجنتين",
    "Category:Deaths by firearm in Arizona": "تصنيف:وفيات بإطلاق النار في أريزونا",
    "Category:Deaths by firearm in Arkansas": "تصنيف:وفيات بإطلاق النار في أركنساس",
    "Category:Deaths by firearm in Armenia": "تصنيف:وفيات بإطلاق النار في أرمينيا",
    "Category:Deaths by firearm in Australia": "تصنيف:وفيات بإطلاق النار في أستراليا",
    "Category:Deaths by firearm in Azerbaijan": "تصنيف:وفيات بإطلاق النار في أذربيجان",
    "Category:Deaths by firearm in Bangladesh": "تصنيف:وفيات بإطلاق النار في بنغلاديش",
    "Category:Deaths by firearm in Belgium": "تصنيف:وفيات بإطلاق النار في بلجيكا",
    "Category:Deaths by firearm in Bolivia": "تصنيف:وفيات بإطلاق النار في بوليفيا",
    "Category:Deaths by firearm in Bosnia and Herzegovina": "تصنيف:وفيات بإطلاق النار في البوسنة والهرسك",
    "Category:Deaths by firearm in Brazil": "تصنيف:وفيات بإطلاق النار في البرازيل",
    "Category:Deaths by firearm in British Columbia": "تصنيف:وفيات بإطلاق النار في كولومبيا البريطانية",
    "Category:Deaths by firearm in British Malaya": "تصنيف:وفيات بإطلاق النار في ملايا البريطانية",
    "Category:Deaths by firearm in Brooklyn": "تصنيف:وفيات بإطلاق النار في بروكلين",
    "Category:Deaths by firearm in Bulgaria": "تصنيف:وفيات بإطلاق النار في بلغاريا",
    "Category:Deaths by firearm in Burundi": "تصنيف:وفيات بإطلاق النار في بوروندي",
    "Category:Deaths by firearm in California": "تصنيف:وفيات بإطلاق النار في كاليفورنيا",
    "Category:Deaths by firearm in Cambodia": "تصنيف:وفيات بإطلاق النار في كمبوديا",
    "Category:Deaths by firearm in Canada": "تصنيف:وفيات بإطلاق النار في كندا",
    "Category:Deaths by firearm in Chad": "تصنيف:وفيات بإطلاق النار في تشاد",
    "Category:Deaths by firearm in Chile": "تصنيف:وفيات بإطلاق النار في تشيلي",
    "Category:Deaths by firearm in Colombia": "تصنيف:وفيات بإطلاق النار في كولومبيا",
    "Category:Deaths by firearm in Colorado": "تصنيف:وفيات بإطلاق النار في كولورادو",
    "Category:Deaths by firearm in Connecticut": "تصنيف:وفيات بإطلاق النار في كونيتيكت",
    "Category:Deaths by firearm in Costa Rica": "تصنيف:وفيات بإطلاق النار في كوستاريكا",
    "Category:Deaths by firearm in Croatia": "تصنيف:وفيات بإطلاق النار في كرواتيا",
    "Category:Deaths by firearm in Cuba": "تصنيف:وفيات بإطلاق النار في كوبا",
    "Category:Deaths by firearm in Cyprus": "تصنيف:وفيات بإطلاق النار في قبرص",
    "Category:Deaths by firearm in Czechoslovakia": "تصنيف:وفيات بإطلاق النار في تشيكوسلوفاكيا",
    "Category:Deaths by firearm in Denmark": "تصنيف:وفيات بإطلاق النار في الدنمارك",
    "Category:Deaths by firearm in East Germany": "تصنيف:وفيات بإطلاق النار في ألمانيا الشرقية",
    "Category:Deaths by firearm in East Timor": "تصنيف:وفيات بإطلاق النار في تيمور الشرقية",
    "Category:Deaths by firearm in Ecuador": "تصنيف:وفيات بإطلاق النار في الإكوادور",
    "Category:Deaths by firearm in Egypt": "تصنيف:وفيات بإطلاق النار في مصر",
    "Category:Deaths by firearm in El Salvador": "تصنيف:وفيات بإطلاق النار في السلفادور",
    "Category:Deaths by firearm in England": "تصنيف:وفيات بإطلاق النار في إنجلترا",
    "Category:Deaths by firearm in Equatorial Guinea": "تصنيف:وفيات بإطلاق النار في غينيا الاستوائية",
    "Category:Deaths by firearm in Estonia": "تصنيف:وفيات بإطلاق النار في إستونيا",
    "Category:Deaths by firearm in Ethiopia": "تصنيف:وفيات بإطلاق النار في إثيوبيا",
    "Category:Deaths by firearm in Finland": "تصنيف:وفيات بإطلاق النار في فنلندا",
    "Category:Deaths by firearm in Georgia (country)": "تصنيف:وفيات بإطلاق النار في جورجيا",
    "Category:Deaths by firearm in Georgia (U.S. state)": "تصنيف:وفيات بإطلاق النار في ولاية جورجيا",
    "Category:Deaths by firearm in Germany": "تصنيف:وفيات بإطلاق النار في ألمانيا",
    "Category:Deaths by firearm in Ghana": "تصنيف:وفيات بإطلاق النار في غانا",
    "Category:Deaths by firearm in Gibraltar": "تصنيف:وفيات بإطلاق النار في جبل طارق",
    "Category:Deaths by firearm in Guadeloupe": "تصنيف:وفيات بإطلاق النار في غوادلوب",
    "Category:Deaths by firearm in Guatemala": "تصنيف:وفيات بإطلاق النار في غواتيمالا",
    "Category:Deaths by firearm in Guinea": "تصنيف:وفيات بإطلاق النار في غينيا",
    "Category:Deaths by firearm in Guinea-Bissau": "تصنيف:وفيات بإطلاق النار في غينيا بيساو",
    "Category:Deaths by firearm in Guyana": "تصنيف:وفيات بإطلاق النار في غيانا",
    "Category:Deaths by firearm in Haiti": "تصنيف:وفيات بإطلاق النار في هايتي",
    "Category:Deaths by firearm in Hawaii": "تصنيف:وفيات بإطلاق النار في هاواي",
    "Category:Deaths by firearm in Hungary": "تصنيف:وفيات بإطلاق النار في المجر",
    "Category:Deaths by firearm in Idaho": "تصنيف:وفيات بإطلاق النار في أيداهو",
    "Category:Deaths by firearm in Illinois": "تصنيف:وفيات بإطلاق النار في إلينوي",
    "Category:Deaths by firearm in India": "تصنيف:وفيات بإطلاق النار في الهند",
    "Category:Deaths by firearm in Indiana": "تصنيف:وفيات بإطلاق النار في إنديانا",
    "Category:Deaths by firearm in Indonesia": "تصنيف:وفيات بإطلاق النار في إندونيسيا",
    "Category:Deaths by firearm in insular areas of the United States": "تصنيف:وفيات بإطلاق النار في المناطق المعزولة في الولايات المتحدة",
    "Category:Deaths by firearm in Iowa": "تصنيف:وفيات بإطلاق النار في آيوا",
    "Category:Deaths by firearm in Ireland": "تصنيف:وفيات بإطلاق النار في أيرلندا",
    "Category:Deaths by firearm in Islamabad": "تصنيف:وفيات بإطلاق النار في إسلام آباد",
    "Category:Deaths by firearm in Israel": "تصنيف:وفيات بإطلاق النار في إسرائيل",
    "Category:Deaths by firearm in Italy": "تصنيف:وفيات بإطلاق النار في إيطاليا",
    "Category:Deaths by firearm in Ivory Coast": "تصنيف:وفيات بإطلاق النار في ساحل العاج",
    "Category:Deaths by firearm in Jamaica": "تصنيف:وفيات بإطلاق النار في جامايكا",
    "Category:Deaths by firearm in Japan": "تصنيف:وفيات بإطلاق النار في اليابان",
    "Category:Deaths by firearm in Kansas": "تصنيف:وفيات بإطلاق النار في كانساس",
    "Category:Deaths by firearm in Kentucky": "تصنيف:وفيات بإطلاق النار في كنتاكي",
    "Category:Deaths by firearm in Kenya": "تصنيف:وفيات بإطلاق النار في كينيا",
    "Category:Deaths by firearm in Korea": "تصنيف:وفيات بإطلاق النار في كوريا",
    "Category:Deaths by firearm in Kosovo": "تصنيف:وفيات بإطلاق النار في كوسوفو",
    "Category:Deaths by firearm in Kuwait": "تصنيف:وفيات بإطلاق النار في الكويت",
    "Category:Deaths by firearm in Liberia": "تصنيف:وفيات بإطلاق النار في ليبيريا",
    "Category:Deaths by firearm in Libya": "تصنيف:وفيات بإطلاق النار في ليبيا",
    "Category:Deaths by firearm in Lithuania": "تصنيف:وفيات بإطلاق النار في ليتوانيا",
    "Category:Deaths by firearm in London": "تصنيف:وفيات بإطلاق النار في لندن",
    "Category:Deaths by firearm in Louisiana": "تصنيف:وفيات بإطلاق النار في لويزيانا",
    "Category:Deaths by firearm in Luxembourg": "تصنيف:وفيات بإطلاق النار في لوكسمبورغ",
    "Category:Deaths by firearm in Maine": "تصنيف:وفيات بإطلاق النار في مين",
    "Category:Deaths by firearm in Malaysia": "تصنيف:وفيات بإطلاق النار في ماليزيا",
    "Category:Deaths by firearm in Mali": "تصنيف:وفيات بإطلاق النار في مالي",
    "Category:Deaths by firearm in Malta": "تصنيف:وفيات بإطلاق النار في مالطا",
    "Category:Deaths by firearm in Mandatory Palestine": "تصنيف:وفيات بإطلاق النار في الانتداب البريطاني على فلسطين",
    "Category:Deaths by firearm in Manhattan": "تصنيف:وفيات بإطلاق النار في مانهاتن",
    "Category:Deaths by firearm in Maryland": "تصنيف:وفيات بإطلاق النار في ماريلند",
    "Category:Deaths by firearm in Massachusetts": "تصنيف:وفيات بإطلاق النار في ماساتشوستس",
    "Category:Deaths by firearm in Mauritania": "تصنيف:وفيات بإطلاق النار في موريتانيا",
    "Category:Deaths by firearm in Mexico": "تصنيف:وفيات بإطلاق النار في المكسيك",
    "Category:Deaths by firearm in Michigan": "تصنيف:وفيات بإطلاق النار في ميشيغان",
    "Category:Deaths by firearm in Mississippi": "تصنيف:وفيات بإطلاق النار في مسيسيبي",
    "Category:Deaths by firearm in Missouri": "تصنيف:وفيات بإطلاق النار في ميزوري",
    "Category:Deaths by firearm in Montana": "تصنيف:وفيات بإطلاق النار في مونتانا",
    "Category:Deaths by firearm in Montenegro": "تصنيف:وفيات بإطلاق النار في الجبل الأسود",
    "Category:Deaths by firearm in Montreal": "تصنيف:وفيات بإطلاق النار في مونتريال",
    "Category:Deaths by firearm in Morocco": "تصنيف:وفيات بإطلاق النار في المغرب",
    "Category:Deaths by firearm in Mozambique": "تصنيف:وفيات بإطلاق النار في موزمبيق",
    "Category:Deaths by firearm in Myanmar": "تصنيف:وفيات بإطلاق النار في ميانمار",
    "Category:Deaths by firearm in Nebraska": "تصنيف:وفيات بإطلاق النار في نبراسكا",
    "Category:Deaths by firearm in Nepal": "تصنيف:وفيات بإطلاق النار في نيبال",
    "Category:Deaths by firearm in Nevada": "تصنيف:وفيات بإطلاق النار في نيفادا",
    "Category:Deaths by firearm in New Hampshire": "تصنيف:وفيات بإطلاق النار في نيوهامشير",
    "Category:Deaths by firearm in New Jersey": "تصنيف:وفيات بإطلاق النار في نيوجيرسي",
    "Category:Deaths by firearm in New Mexico": "تصنيف:وفيات بإطلاق النار في نيومكسيكو",
    "Category:Deaths by firearm in New South Wales": "تصنيف:وفيات بإطلاق النار في نيوساوث ويلز",
    "Category:Deaths by firearm in New York (state)": "تصنيف:وفيات بإطلاق النار في ولاية نيويورك",
    "Category:Deaths by firearm in New York City": "تصنيف:وفيات بإطلاق النار في مدينة نيويورك",
    "Category:Deaths by firearm in New Zealand": "تصنيف:وفيات بإطلاق النار في نيوزيلندا",
    "Category:Deaths by firearm in Nicaragua": "تصنيف:وفيات بإطلاق النار في نيكاراغوا",
    "Category:Deaths by firearm in Niger": "تصنيف:وفيات بإطلاق النار في النيجر",
    "Category:Deaths by firearm in Nigeria": "تصنيف:وفيات بإطلاق النار في نيجيريا",
    "Category:Deaths by firearm in North America": "تصنيف:وفيات بإطلاق النار في أمريكا الشمالية",
    "Category:Deaths by firearm in North Carolina": "تصنيف:وفيات بإطلاق النار في كارولاينا الشمالية",
    "Category:Deaths by firearm in North Korea": "تصنيف:وفيات بإطلاق النار في كوريا الشمالية",
    "Category:Deaths by firearm in Northern Ireland": "تصنيف:وفيات بإطلاق النار في أيرلندا الشمالية",
    "Category:Deaths by firearm in Norway": "تصنيف:وفيات بإطلاق النار في النرويج",
    "Category:Deaths by firearm in Nova Scotia": "تصنيف:وفيات بإطلاق النار في نوفا سكوشا",
    "Category:Deaths by firearm in Ohio": "تصنيف:وفيات بإطلاق النار في أوهايو",
    "Category:Deaths by firearm in Oklahoma": "تصنيف:وفيات بإطلاق النار في أوكلاهوما",
    "Category:Deaths by firearm in Ontario": "تصنيف:وفيات بإطلاق النار في أونتاريو",
    "Category:Deaths by firearm in Pakistan": "تصنيف:وفيات بإطلاق النار في باكستان",
    "Category:Deaths by firearm in Palau": "تصنيف:وفيات بإطلاق النار في بالاو",
    "Category:Deaths by firearm in Palestine": "تصنيف:وفيات بإطلاق النار في فلسطين",
    "Category:Deaths by firearm in Panama": "تصنيف:وفيات بإطلاق النار في بنما",
    "Category:Deaths by firearm in Papua New Guinea": "تصنيف:وفيات بإطلاق النار في بابوا غينيا الجديدة",
    "Category:Deaths by firearm in Paraguay": "تصنيف:وفيات بإطلاق النار في باراغواي",
    "Category:Deaths by firearm in Pennsylvania": "تصنيف:وفيات بإطلاق النار في بنسلفانيا",
    "Category:Deaths by firearm in Peru": "تصنيف:وفيات بإطلاق النار في بيرو",
    "Category:Deaths by firearm in Poland": "تصنيف:وفيات بإطلاق النار في بولندا",
    "Category:Deaths by firearm in Portugal": "تصنيف:وفيات بإطلاق النار في البرتغال",
    "Category:Deaths by firearm in Puerto Rico": "تصنيف:وفيات بإطلاق النار في بورتوريكو",
    "Category:Deaths by firearm in Quebec": "تصنيف:وفيات بإطلاق النار في كيبك",
    "Category:Deaths by firearm in Queens, New York": "تصنيف:وفيات بإطلاق النار في كوينز (نيويورك)",
    "Category:Deaths by firearm in Queensland": "تصنيف:وفيات بإطلاق النار في كوينزلاند",
    "Category:Deaths by firearm in Rhode Island": "تصنيف:وفيات بإطلاق النار في رود آيلاند",
    "Category:Deaths by firearm in Rhodesia": "تصنيف:وفيات بإطلاق النار في رودسيا",
    "Category:Deaths by firearm in Romania": "تصنيف:وفيات بإطلاق النار في رومانيا",
    "Category:Deaths by firearm in Russia": "تصنيف:وفيات بإطلاق النار في روسيا",
    "Category:Deaths by firearm in Rwanda": "تصنيف:وفيات بإطلاق النار في رواندا",
    "Category:Deaths by firearm in San Francisco": "تصنيف:وفيات بإطلاق النار في سان فرانسيسكو",
    "Category:Deaths by firearm in Scotland": "تصنيف:وفيات بإطلاق النار في إسكتلندا",
    "Category:Deaths by firearm in Senegal": "تصنيف:وفيات بإطلاق النار في السنغال",
    "Category:Deaths by firearm in Serbia": "تصنيف:وفيات بإطلاق النار في صربيا",
    "Category:Deaths by firearm in Sindh": "تصنيف:وفيات بإطلاق النار في إقليم السند",
    "Category:Deaths by firearm in Slovakia": "تصنيف:وفيات بإطلاق النار في سلوفاكيا",
    "Category:Deaths by firearm in Slovenia": "تصنيف:وفيات بإطلاق النار في سلوفينيا",
    "Category:Deaths by firearm in Somalia": "تصنيف:وفيات بإطلاق النار في الصومال",
    "Category:Deaths by firearm in South Carolina": "تصنيف:وفيات بإطلاق النار في كارولاينا الجنوبية",
    "Category:Deaths by firearm in South Dakota": "تصنيف:وفيات بإطلاق النار في داكوتا الجنوبية",
    "Category:Deaths by firearm in South Korea": "تصنيف:وفيات بإطلاق النار في كوريا الجنوبية",
    "Category:Deaths by firearm in Spain": "تصنيف:وفيات بإطلاق النار في إسبانيا",
    "Category:Deaths by firearm in Sri Lanka": "تصنيف:وفيات بإطلاق النار في سريلانكا",
    "Category:Deaths by firearm in Suriname": "تصنيف:وفيات بإطلاق النار في سورينام",
    "Category:Deaths by firearm in Sweden": "تصنيف:وفيات بإطلاق النار في السويد",
    "Category:Deaths by firearm in Switzerland": "تصنيف:وفيات بإطلاق النار في سويسرا",
    "Category:Deaths by firearm in Taiwan": "تصنيف:وفيات بإطلاق النار في تايوان",
    "Category:Deaths by firearm in Tanzania": "تصنيف:وفيات بإطلاق النار في تنزانيا",
    "Category:Deaths by firearm in Tennessee": "تصنيف:وفيات بإطلاق النار في تينيسي",
    "Category:Deaths by firearm in the Bronx": "تصنيف:وفيات بإطلاق النار في ذا برونكس",
    "Category:Deaths by firearm in the Central African Republic": "تصنيف:وفيات بإطلاق النار في جمهورية إفريقيا الوسطى",
    "Category:Deaths by firearm in the Comoros": "تصنيف:وفيات بإطلاق النار في جزر القمر",
    "Category:Deaths by firearm in the Czech Republic": "تصنيف:وفيات بإطلاق النار في التشيك",
    "Category:Deaths by firearm in the Democratic Republic of the Congo": "تصنيف:وفيات بإطلاق النار في جمهورية الكونغو الديمقراطية",
    "Category:Deaths by firearm in the Dominican Republic": "تصنيف:وفيات بإطلاق النار في جمهورية الدومينيكان",
    "Category:Deaths by firearm in the Gaza Strip": "تصنيف:وفيات بإطلاق النار في قطاع غزة",
    "Category:Deaths by firearm in the Netherlands": "تصنيف:وفيات بإطلاق النار في هولندا",
    "Category:Deaths by firearm in the Northern Mariana Islands": "تصنيف:وفيات بإطلاق النار في جزر ماريانا الشمالية",
    "Category:Deaths by firearm in the Northern Territory": "تصنيف:وفيات بإطلاق النار في الإقليم الشمالي",
    "Category:Deaths by firearm in the Palestinian territories": "تصنيف:وفيات بإطلاق النار في الضفة الغربية وقطاع غزة",
    "Category:Deaths by firearm in the Philippines": "تصنيف:وفيات بإطلاق النار في الفلبين",
    "Category:Deaths by firearm in the Republic of Ireland": "تصنيف:وفيات بإطلاق النار في جمهورية أيرلندا",
    "Category:Deaths by firearm in the Republic of the Congo": "تصنيف:وفيات بإطلاق النار في جمهورية الكونغو",
    "Category:Deaths by firearm in the Soviet Union": "تصنيف:وفيات بإطلاق النار في الاتحاد السوفيتي",
    "Category:Deaths by firearm in the United Arab Emirates": "تصنيف:وفيات بإطلاق النار في الإمارات العربية المتحدة",
    "Category:Deaths by firearm in the United Kingdom": "تصنيف:وفيات بإطلاق النار في المملكة المتحدة",
    "Category:Deaths by firearm in the West Bank": "تصنيف:وفيات بإطلاق النار في الضفة الغربية",
    "Category:Deaths by firearm in Togo": "تصنيف:وفيات بإطلاق النار في توغو",
    "Category:Deaths by firearm in Uganda": "تصنيف:وفيات بإطلاق النار في أوغندا",
    "Category:Deaths by firearm in Ukraine": "تصنيف:وفيات بإطلاق النار في أوكرانيا",
    "Category:Deaths by firearm in Utah": "تصنيف:وفيات بإطلاق النار في يوتا",
    "Category:Deaths by firearm in Vermont": "تصنيف:وفيات بإطلاق النار في فيرمونت",
    "Category:Deaths by firearm in Vietnam": "تصنيف:وفيات بإطلاق النار في فيتنام",
    "Category:Deaths by firearm in Virginia": "تصنيف:وفيات بإطلاق النار في فرجينيا",
    "Category:Deaths by firearm in Wales": "تصنيف:وفيات بإطلاق النار في ويلز",
    "Category:Deaths by firearm in Washington (state)": "تصنيف:وفيات بإطلاق النار في ولاية واشنطن",
    "Category:Deaths by firearm in Washington, D.C.": "تصنيف:وفيات بإطلاق النار في واشنطن العاصمة",
    "Category:Deaths by firearm in Western Australia": "تصنيف:وفيات بإطلاق النار في أستراليا الغربية",
    "Category:Deaths by firearm in Wisconsin": "تصنيف:وفيات بإطلاق النار في ويسكونسن",
    "Category:Deaths by firearm in Yugoslavia": "تصنيف:وفيات بإطلاق النار في يوغسلافيا",
    "Category:Deaths by firearm in Zimbabwe": "تصنيف:وفيات بإطلاق النار في زيمبابوي",
    "Category:Deaths by Israeli airstrikes": "تصنيف:وفيات بضربات جوية إسرائيلية",
    "Category:Deaths by location": "تصنيف:وفيات حسب الموقع",
    "Category:Deaths by millennium": "تصنيف:وفيات حسب الألفية",
    "Category:Deaths by organization": "تصنيف:وفيات حسب المنظمة",
    "Category:Deaths by Pakistani airstrikes": "تصنيف:وفيات بضربات جوية باكستانية",
    "Category:Deaths by period": "تصنيف:وفيات حسب الحقبة",
    "Category:Deaths by perpetrator": "تصنيف:وفيات حسب مرتكب الجريمة",
    "Category:Deaths by person and country": "تصنيف:وفيات حسب الشخص والبلد",
    "Category:Deaths by person in Africa": "تصنيف:وفيات حسب الشخص في إفريقيا",
    "Category:Deaths by person in Alabama": "تصنيف:وفيات حسب الشخص في ألاباما",
    "Category:Deaths by person in Algeria": "تصنيف:وفيات حسب الشخص في الجزائر",
    "Category:Deaths by person in Argentina": "تصنيف:وفيات حسب الشخص في الأرجنتين",
    "Category:Deaths by person in Arizona": "تصنيف:وفيات حسب الشخص في أريزونا",
    "Category:Deaths by person in Arkansas": "تصنيف:وفيات حسب الشخص في أركنساس",
    "Category:Deaths by person in Armenia": "تصنيف:وفيات حسب الشخص في أرمينيا",
    "Category:Deaths by person in Asia": "تصنيف:وفيات حسب الشخص في آسيا",
    "Category:Deaths by person in Australia": "تصنيف:وفيات حسب الشخص في أستراليا",
    "Category:Deaths by person in Bahrain": "تصنيف:وفيات حسب الشخص في البحرين",
    "Category:Deaths by person in Bangladesh": "تصنيف:وفيات حسب الشخص في بنغلاديش",
    "Category:Deaths by person in Belgium": "تصنيف:وفيات حسب الشخص في بلجيكا",
    "Category:Deaths by person in Bosnia and Herzegovina": "تصنيف:وفيات حسب الشخص في البوسنة والهرسك",
    "Category:Deaths by person in California": "تصنيف:وفيات حسب الشخص في كاليفورنيا",
    "Category:Deaths by person in Canada": "تصنيف:وفيات حسب الشخص في كندا",
    "Category:Deaths by person in Chile": "تصنيف:وفيات حسب الشخص في تشيلي",
    "Category:Deaths by person in China": "تصنيف:وفيات حسب الشخص في الصين",
    "Category:Deaths by person in Colorado": "تصنيف:وفيات حسب الشخص في كولورادو",
    "Category:Deaths by person in Connecticut": "تصنيف:وفيات حسب الشخص في كونيتيكت",
    "Category:Deaths by person in Denmark": "تصنيف:وفيات حسب الشخص في الدنمارك",
    "Category:Deaths by person in Ecuador": "تصنيف:وفيات حسب الشخص في الإكوادور",
    "Category:Deaths by person in Egypt": "تصنيف:وفيات حسب الشخص في مصر",
    "Category:Deaths by person in England": "تصنيف:وفيات حسب الشخص في إنجلترا",
    "Category:Deaths by person in Ethiopia": "تصنيف:وفيات حسب الشخص في إثيوبيا",
    "Category:Deaths by person in Europe": "تصنيف:وفيات حسب الشخص في أوروبا",
    "Category:Deaths by person in Finland": "تصنيف:وفيات حسب الشخص في فنلندا",
    "Category:Deaths by person in Florida": "تصنيف:وفيات حسب الشخص في فلوريدا",
    "Category:Deaths by person in France": "تصنيف:وفيات حسب الشخص في فرنسا",
    "Category:Deaths by person in Georgia (U.S. state)": "تصنيف:وفيات حسب الشخص في ولاية جورجيا",
    "Category:Deaths by person in Germany": "تصنيف:وفيات حسب الشخص في ألمانيا",
    "Category:Deaths by person in Haiti": "تصنيف:وفيات حسب الشخص في هايتي",
    "Category:Deaths by person in Hong Kong": "تصنيف:وفيات حسب الشخص في هونغ كونغ",
    "Category:Deaths by person in Idaho": "تصنيف:وفيات حسب الشخص في أيداهو",
    "Category:Deaths by person in Illinois": "تصنيف:وفيات حسب الشخص في إلينوي",
    "Category:Deaths by person in India": "تصنيف:وفيات حسب الشخص في الهند",
    "Category:Deaths by person in Indiana": "تصنيف:وفيات حسب الشخص في إنديانا",
    "Category:Deaths by person in Indonesia": "تصنيف:وفيات حسب الشخص في إندونيسيا",
    "Category:Deaths by person in Iran": "تصنيف:وفيات حسب الشخص في إيران",
    "Category:Deaths by person in Iraq": "تصنيف:وفيات حسب الشخص في العراق",
    "Category:Deaths by person in Israel": "تصنيف:وفيات حسب الشخص في إسرائيل",
    "Category:Deaths by person in Italy": "تصنيف:وفيات حسب الشخص في إيطاليا",
    "Category:Deaths by person in Japan": "تصنيف:وفيات حسب الشخص في اليابان",
    "Category:Deaths by person in Jerusalem": "تصنيف:وفيات حسب الشخص في القدس",
    "Category:Deaths by person in Jordan": "تصنيف:وفيات حسب الشخص في الأردن",
    "Category:Deaths by person in Kansas": "تصنيف:وفيات حسب الشخص في كانساس",
    "Category:Deaths by person in Kentucky": "تصنيف:وفيات حسب الشخص في كنتاكي",
    "Category:Deaths by person in Kuwait": "تصنيف:وفيات حسب الشخص في الكويت",
    "Category:Deaths by person in Libya": "تصنيف:وفيات حسب الشخص في ليبيا",
    "Category:Deaths by person in London": "تصنيف:وفيات حسب الشخص في لندن",
    "Category:Deaths by person in Los Angeles": "تصنيف:وفيات حسب الشخص في لوس أنجلوس",
    "Category:Deaths by person in Louisiana": "تصنيف:وفيات حسب الشخص في لويزيانا",
    "Category:Deaths by person in Maine": "تصنيف:وفيات حسب الشخص في مين",
    "Category:Deaths by person in Malaysia": "تصنيف:وفيات حسب الشخص في ماليزيا",
    "Category:Deaths by person in Maryland": "تصنيف:وفيات حسب الشخص في ماريلند",
    "Category:Deaths by person in Massachusetts": "تصنيف:وفيات حسب الشخص في ماساتشوستس",
    "Category:Deaths by person in Mexico": "تصنيف:وفيات حسب الشخص في المكسيك",
    "Category:Deaths by person in Mississippi": "تصنيف:وفيات حسب الشخص في مسيسيبي",
    "Category:Deaths by person in Missouri": "تصنيف:وفيات حسب الشخص في ميزوري",
    "Category:Deaths by person in Moldova": "تصنيف:وفيات حسب الشخص في مولدوفا",
    "Category:Deaths by person in Morocco": "تصنيف:وفيات حسب الشخص في المغرب",
    "Category:Deaths by person in Moscow": "تصنيف:وفيات حسب الشخص في موسكو",
    "Category:Deaths by person in Nevada": "تصنيف:وفيات حسب الشخص في نيفادا",
    "Category:Deaths by person in New Hampshire": "تصنيف:وفيات حسب الشخص في نيوهامشير",
    "Category:Deaths by person in New Jersey": "تصنيف:وفيات حسب الشخص في نيوجيرسي",
    "Category:Deaths by person in New Mexico": "تصنيف:وفيات حسب الشخص في نيومكسيكو",
    "Category:Deaths by person in New York (state)": "تصنيف:وفيات حسب الشخص في ولاية نيويورك",
    "Category:Deaths by person in New York City": "تصنيف:وفيات حسب الشخص في مدينة نيويورك",
    "Category:Deaths by person in North America": "تصنيف:وفيات حسب الشخص في أمريكا الشمالية",
    "Category:Deaths by person in North Carolina": "تصنيف:وفيات حسب الشخص في كارولاينا الشمالية",
    "Category:Deaths by person in North Korea": "تصنيف:وفيات حسب الشخص في كوريا الشمالية",
    "Category:Deaths by person in Norway": "تصنيف:وفيات حسب الشخص في النرويج",
    "Category:Deaths by person in Oceania": "تصنيف:وفيات حسب الشخص في أوقيانوسيا",
    "Category:Deaths by person in Ohio": "تصنيف:وفيات حسب الشخص في أوهايو",
    "Category:Deaths by person in Oklahoma": "تصنيف:وفيات حسب الشخص في أوكلاهوما",
    "Category:Deaths by person in Pakistan": "تصنيف:وفيات حسب الشخص في باكستان",
    "Category:Deaths by person in Panama": "تصنيف:وفيات حسب الشخص في بنما",
    "Category:Deaths by person in Paris": "تصنيف:وفيات حسب الشخص في باريس",
    "Category:Deaths by person in Pennsylvania": "تصنيف:وفيات حسب الشخص في بنسلفانيا",
    "Category:Deaths by person in Russia": "تصنيف:وفيات حسب الشخص في روسيا",
    "Category:Deaths by person in Scotland": "تصنيف:وفيات حسب الشخص في إسكتلندا",
    "Category:Deaths by person in Singapore": "تصنيف:وفيات حسب الشخص في سنغافورة",
    "Category:Deaths by person in Slovakia": "تصنيف:وفيات حسب الشخص في سلوفاكيا",
    "Category:Deaths by person in Slovenia": "تصنيف:وفيات حسب الشخص في سلوفينيا",
    "Category:Deaths by person in South America": "تصنيف:وفيات حسب الشخص في أمريكا الجنوبية",
    "Category:Deaths by person in South Carolina": "تصنيف:وفيات حسب الشخص في كارولاينا الجنوبية",
    "Category:Deaths by person in Spain": "تصنيف:وفيات حسب الشخص في إسبانيا",
    "Category:Deaths by person in Sweden": "تصنيف:وفيات حسب الشخص في السويد",
    "Category:Deaths by person in Syria": "تصنيف:وفيات حسب الشخص في سوريا",
    "Category:Deaths by person in Taiwan": "تصنيف:وفيات حسب الشخص في تايوان",
    "Category:Deaths by person in Tennessee": "تصنيف:وفيات حسب الشخص في تينيسي",
    "Category:Deaths by person in Texas": "تصنيف:وفيات حسب الشخص في تكساس",
    "Category:Deaths by person in Thailand": "تصنيف:وفيات حسب الشخص في تايلاند",
    "Category:Deaths by person in the Democratic Republic of the Congo": "تصنيف:وفيات حسب الشخص في جمهورية الكونغو الديمقراطية",
    "Category:Deaths by person in the Netherlands": "تصنيف:وفيات حسب الشخص في هولندا",
    "Category:Deaths by person in the Philippines": "تصنيف:وفيات حسب الشخص في الفلبين",
    "Category:Deaths by person in the Russian Empire": "تصنيف:وفيات حسب الشخص في الإمبراطورية الروسية",
    "Category:Deaths by person in the United Arab Emirates": "تصنيف:وفيات حسب الشخص في الإمارات العربية المتحدة",
    "Category:Deaths by person in the United Kingdom": "تصنيف:وفيات حسب الشخص في المملكة المتحدة",
    "Category:Deaths by person in the United States": "تصنيف:وفيات حسب الشخص في الولايات المتحدة",
    "Category:Deaths by person in Turkey": "تصنيف:وفيات حسب الشخص في تركيا",
    "Category:Deaths by person in Ukraine": "تصنيف:وفيات حسب الشخص في أوكرانيا",
    "Category:Deaths by person in Utah": "تصنيف:وفيات حسب الشخص في يوتا",
    "Category:Deaths by person in Vatican City": "تصنيف:وفيات حسب الشخص في الفاتيكان",
    "Category:Deaths by person in Venezuela": "تصنيف:وفيات حسب الشخص في فنزويلا",
    "Category:Deaths by person in Vermont": "تصنيف:وفيات حسب الشخص في فيرمونت",
    "Category:Deaths by person in Vietnam": "تصنيف:وفيات حسب الشخص في فيتنام",
    "Category:Deaths by person in Virginia": "تصنيف:وفيات حسب الشخص في فرجينيا",
    "Category:Deaths by person in Wales": "تصنيف:وفيات حسب الشخص في ويلز",
    "Category:Deaths by person in Washington (state)": "تصنيف:وفيات حسب الشخص في ولاية واشنطن",
    "Category:Deaths by person in Washington, D.C.": "تصنيف:وفيات حسب الشخص في واشنطن العاصمة",
    "Category:Deaths by person in Wisconsin": "تصنيف:وفيات حسب الشخص في ويسكونسن",
    "Category:Deaths by person in Wyoming": "تصنيف:وفيات حسب الشخص في وايومنغ",
    "Category:Deaths by person in Yemen": "تصنيف:وفيات حسب الشخص في اليمن",
    "Category:Deaths caused by industrial robots": "تصنيف:وفيات بسبب الروبوتات الصناعية",
    "Category:Deaths caused by petroleum looting": "تصنيف:وفيات بسبب نهب البترول",
    "Category:Deaths due to animal attacks in Australia": "تصنيف:وفيات ناجمة عن هجمات الحيوانات في أستراليا",
    "Category:Deaths due to animal attacks in the United States": "تصنيف:وفيات ناجمة عن هجمات الحيوانات في الولايات المتحدة",
    "Category:Deaths from brain cancer in Argentina": "تصنيف:وفيات سرطان الدماغ في الأرجنتين",
    "Category:Deaths from brain cancer in Australia": "تصنيف:وفيات سرطان الدماغ في أستراليا",
    "Category:Deaths from brain cancer in Austria": "تصنيف:وفيات سرطان الدماغ في النمسا",
    "Category:Deaths from brain cancer in Brazil": "تصنيف:وفيات سرطان الدماغ في البرازيل",
    "Category:Deaths from brain cancer in California": "تصنيف:وفيات سرطان الدماغ في كاليفورنيا",
    "Category:Deaths from brain cancer in Canada": "تصنيف:وفيات سرطان الدماغ في كندا",
    "Category:Deaths from brain cancer in Connecticut": "تصنيف:وفيات سرطان الدماغ في كونيتيكت",
    "Category:Deaths from brain cancer in Egypt": "تصنيف:وفيات سرطان الدماغ في مصر",
    "Category:Deaths from brain cancer in England": "تصنيف:وفيات سرطان الدماغ في إنجلترا",
    "Category:Deaths from brain cancer in Estonia": "تصنيف:وفيات سرطان الدماغ في إستونيا",
    "Category:Deaths from brain cancer in Florida": "تصنيف:وفيات سرطان الدماغ في فلوريدا",
    "Category:Deaths from brain cancer in France": "تصنيف:وفيات سرطان الدماغ في فرنسا",
    "Category:Deaths from brain cancer in Georgia (U.S. state)": "تصنيف:وفيات سرطان الدماغ في ولاية جورجيا",
    "Category:Deaths from brain cancer in Germany": "تصنيف:وفيات سرطان الدماغ في ألمانيا",
    "Category:Deaths from brain cancer in Greece": "تصنيف:وفيات سرطان الدماغ في اليونان",
    "Category:Deaths from brain cancer in India": "تصنيف:وفيات سرطان الدماغ في الهند",
    "Category:Deaths from brain cancer in Indiana": "تصنيف:وفيات سرطان الدماغ في إنديانا",
    "Category:Deaths from brain cancer in Indonesia": "تصنيف:وفيات سرطان الدماغ في إندونيسيا",
    "Category:Deaths from brain cancer in Ireland": "تصنيف:وفيات سرطان الدماغ في أيرلندا",
    "Category:Deaths from brain cancer in Israel": "تصنيف:وفيات سرطان الدماغ في إسرائيل",
    "Category:Deaths from brain cancer in Italy": "تصنيف:وفيات سرطان الدماغ في إيطاليا",
    "Category:Deaths from brain cancer in Japan": "تصنيف:وفيات سرطان الدماغ في اليابان",
    "Category:Deaths from brain cancer in Kenya": "تصنيف:وفيات سرطان الدماغ في كينيا",
    "Category:Deaths from brain cancer in Mexico": "تصنيف:وفيات سرطان الدماغ في المكسيك",
    "Category:Deaths from brain cancer in Mississippi": "تصنيف:وفيات سرطان الدماغ في مسيسيبي",
    "Category:Deaths from brain cancer in New Jersey": "تصنيف:وفيات سرطان الدماغ في نيوجيرسي",
    "Category:Deaths from brain cancer in New York (state)": "تصنيف:وفيات سرطان الدماغ في ولاية نيويورك",
    "Category:Deaths from brain cancer in New Zealand": "تصنيف:وفيات سرطان الدماغ في نيوزيلندا",
    "Category:Deaths from brain cancer in Northern Ireland": "تصنيف:وفيات سرطان الدماغ في أيرلندا الشمالية",
    "Category:Deaths from brain cancer in Norway": "تصنيف:وفيات سرطان الدماغ في النرويج",
    "Category:Deaths from brain cancer in Ohio": "تصنيف:وفيات سرطان الدماغ في أوهايو",
    "Category:Deaths from brain cancer in Oregon": "تصنيف:وفيات سرطان الدماغ في أوريغن",
    "Category:Deaths from brain cancer in Pennsylvania": "تصنيف:وفيات سرطان الدماغ في بنسلفانيا",
    "Category:Deaths from brain cancer in Portugal": "تصنيف:وفيات سرطان الدماغ في البرتغال",
    "Category:Deaths from brain cancer in Puerto Rico": "تصنيف:وفيات سرطان الدماغ في بورتوريكو",
    "Category:Deaths from brain cancer in Romania": "تصنيف:وفيات سرطان الدماغ في رومانيا",
    "Category:Deaths from brain cancer in Russia": "تصنيف:وفيات سرطان الدماغ في روسيا",
    "Category:Deaths from brain cancer in Scotland": "تصنيف:وفيات سرطان الدماغ في إسكتلندا",
    "Category:Deaths from brain cancer in Serbia": "تصنيف:وفيات سرطان الدماغ في صربيا",
    "Category:Deaths from brain cancer in Spain": "تصنيف:وفيات سرطان الدماغ في إسبانيا",
    "Category:Deaths from brain cancer in Sweden": "تصنيف:وفيات سرطان الدماغ في السويد",
    "Category:Deaths from brain cancer in Switzerland": "تصنيف:وفيات سرطان الدماغ في سويسرا",
    "Category:Deaths from brain cancer in Texas": "تصنيف:وفيات سرطان الدماغ في تكساس",
    "Category:Deaths from brain cancer in the Netherlands": "تصنيف:وفيات سرطان الدماغ في هولندا",
    "Category:Deaths from brain cancer in the Republic of Ireland": "تصنيف:وفيات سرطان الدماغ في جمهورية أيرلندا",
    "Category:Deaths from brain cancer in the United Kingdom": "تصنيف:وفيات سرطان الدماغ في المملكة المتحدة",
    "Category:Deaths from brain cancer in the United States": "تصنيف:وفيات سرطان الدماغ في الولايات المتحدة",
    "Category:Deaths from brain cancer in Turkey": "تصنيف:وفيات سرطان الدماغ في تركيا",
    "Category:Deaths from brain cancer in Ukraine": "تصنيف:وفيات سرطان الدماغ في أوكرانيا",
    "Category:Deaths from brain cancer in Washington, D.C.": "تصنيف:وفيات سرطان الدماغ في واشنطن العاصمة",
    "Category:Deaths from brain cancer in West Virginia": "تصنيف:وفيات سرطان الدماغ في فرجينيا الغربية",
    "Category:Deaths from cancer by country subdivision": "تصنيف:وفيات السرطان حسب تقسيم البلد",
    "Category:Deaths from cancer by country": "تصنيف:وفيات السرطان حسب البلد",
    "Category:Deaths from cancer by former country": "تصنيف:وفيات السرطان حسب البلد السابق",
    "Category:Deaths from cancer in Abruzzo": "تصنيف:وفيات السرطان في أبروتسو",
    "Category:Deaths from cancer in Alabama": "تصنيف:وفيات السرطان في ألاباما",
    "Category:Deaths from cancer in Alaska": "تصنيف:وفيات السرطان في ألاسكا",
    "Category:Deaths from cancer in Alberta": "تصنيف:وفيات السرطان في ألبرتا",
    "Category:Deaths from cancer in Algeria": "تصنيف:وفيات السرطان في الجزائر",
    "Category:Deaths from cancer in Amazonas (Brazilian state)": "تصنيف:وفيات السرطان في الأمازون (ولاية)",
    "Category:Deaths from cancer in Apulia": "تصنيف:وفيات السرطان في بوليا",
    "Category:Deaths from cancer in Argentina": "تصنيف:وفيات السرطان في الأرجنتين",
    "Category:Deaths from cancer in Arizona": "تصنيف:وفيات السرطان في أريزونا",
    "Category:Deaths from cancer in Arkansas": "تصنيف:وفيات السرطان في أركنساس",
    "Category:Deaths from cancer in Australia by state or territory": "تصنيف:وفيات السرطان في أستراليا حسب الولاية أو الإقليم",
    "Category:Deaths from cancer in Australia": "تصنيف:وفيات السرطان في أستراليا",
    "Category:Deaths from cancer in Austria": "تصنيف:وفيات السرطان في النمسا",
    "Category:Deaths from cancer in Austria-Hungary": "تصنيف:وفيات السرطان في الإمبراطورية النمساوية المجرية",
    "Category:Deaths from cancer in Azerbaijan": "تصنيف:وفيات السرطان في أذربيجان",
    "Category:Deaths from cancer in Bahia": "تصنيف:وفيات السرطان في باهيا",
    "Category:Deaths from cancer in Bahrain": "تصنيف:وفيات السرطان في البحرين",
    "Category:Deaths from cancer in Barbados": "تصنيف:وفيات السرطان في بربادوس",
    "Category:Deaths from cancer in Belarus": "تصنيف:وفيات السرطان في روسيا البيضاء",
    "Category:Deaths from cancer in Belgium": "تصنيف:وفيات السرطان في بلجيكا",
    "Category:Deaths from cancer in Belize": "تصنيف:وفيات السرطان في بليز",
    "Category:Deaths from cancer in Bermuda": "تصنيف:وفيات السرطان في برمودا",
    "Category:Deaths from cancer in Bolivia": "تصنيف:وفيات السرطان في بوليفيا",
    "Category:Deaths from cancer in Bosnia and Herzegovina": "تصنيف:وفيات السرطان في البوسنة والهرسك",
    "Category:Deaths from cancer in Botswana": "تصنيف:وفيات السرطان في بوتسوانا",
    "Category:Deaths from cancer in Brazil by state": "تصنيف:وفيات السرطان في البرازيل حسب الولاية",
    "Category:Deaths from cancer in Brazil": "تصنيف:وفيات السرطان في البرازيل",
    "Category:Deaths from cancer in British Columbia": "تصنيف:وفيات السرطان في كولومبيا البريطانية",
    "Category:Deaths from cancer in Bulgaria": "تصنيف:وفيات السرطان في بلغاريا",
    "Category:Deaths from cancer in Calabria": "تصنيف:وفيات السرطان في كالابريا",
    "Category:Deaths from cancer in California": "تصنيف:وفيات السرطان في كاليفورنيا",
    "Category:Deaths from cancer in Cameroon": "تصنيف:وفيات السرطان في الكاميرون",
    "Category:Deaths from cancer in Campania": "تصنيف:وفيات السرطان في كامبانيا",
    "Category:Deaths from cancer in Canada by province or territory": "تصنيف:وفيات السرطان في كندا حسب المقاطعة أو الإقليم",
    "Category:Deaths from cancer in Canada": "تصنيف:وفيات السرطان في كندا",
    "Category:Deaths from cancer in Chile": "تصنيف:وفيات السرطان في تشيلي",
    "Category:Deaths from cancer in China": "تصنيف:وفيات السرطان في الصين",
    "Category:Deaths from cancer in Colombia": "تصنيف:وفيات السرطان في كولومبيا",
    "Category:Deaths from cancer in Connecticut": "تصنيف:وفيات السرطان في كونيتيكت",
    "Category:Deaths from cancer in Costa Rica": "تصنيف:وفيات السرطان في كوستاريكا",
    "Category:Deaths from cancer in Croatia": "تصنيف:وفيات السرطان في كرواتيا",
    "Category:Deaths from cancer in Cuba": "تصنيف:وفيات السرطان في كوبا",
    "Category:Deaths from cancer in Cyprus": "تصنيف:وفيات السرطان في قبرص",
    "Category:Deaths from cancer in Czechoslovakia": "تصنيف:وفيات السرطان في تشيكوسلوفاكيا",
    "Category:Deaths from cancer in Delaware": "تصنيف:وفيات السرطان في ديلاوير",
    "Category:Deaths from cancer in Denmark": "تصنيف:وفيات السرطان في الدنمارك",
    "Category:Deaths from cancer in Ecuador": "تصنيف:وفيات السرطان في الإكوادور",
    "Category:Deaths from cancer in Egypt": "تصنيف:وفيات السرطان في مصر",
    "Category:Deaths from cancer in El Salvador": "تصنيف:وفيات السرطان في السلفادور",
    "Category:Deaths from cancer in Emilia-Romagna": "تصنيف:وفيات السرطان في إميليا-رومانيا",
    "Category:Deaths from cancer in England": "تصنيف:وفيات السرطان في إنجلترا",
    "Category:Deaths from cancer in Estonia": "تصنيف:وفيات السرطان في إستونيا",
    "Category:Deaths from cancer in Finland": "تصنيف:وفيات السرطان في فنلندا",
    "Category:Deaths from cancer in Florida": "تصنيف:وفيات السرطان في فلوريدا",
    "Category:Deaths from cancer in France": "تصنيف:وفيات السرطان في فرنسا",
    "Category:Deaths from cancer in French Polynesia": "تصنيف:وفيات السرطان في بولينزيا الفرنسية",
    "Category:Deaths from cancer in Germany": "تصنيف:وفيات السرطان في ألمانيا",
    "Category:Deaths from cancer in Ghana": "تصنيف:وفيات السرطان في غانا",
    "Category:Deaths from cancer in Greece": "تصنيف:وفيات السرطان في اليونان",
    "Category:Deaths from cancer in Grenada": "تصنيف:وفيات السرطان في غرينادا",
    "Category:Deaths from cancer in Guam": "تصنيف:وفيات السرطان في غوام",
    "Category:Deaths from cancer in Guatemala": "تصنيف:وفيات السرطان في غواتيمالا",
    "Category:Deaths from cancer in Guinea": "تصنيف:وفيات السرطان في غينيا",
    "Category:Deaths from cancer in Guyana": "تصنيف:وفيات السرطان في غيانا",
    "Category:Deaths from cancer in Hawaii": "تصنيف:وفيات السرطان في هاواي",
    "Category:Deaths from cancer in Honduras": "تصنيف:وفيات السرطان في هندوراس",
    "Category:Deaths from cancer in Hong Kong": "تصنيف:وفيات السرطان في هونغ كونغ",
    "Category:Deaths from cancer in Hungary": "تصنيف:وفيات السرطان في المجر",
    "Category:Deaths from cancer in Iceland": "تصنيف:وفيات السرطان في آيسلندا",
    "Category:Deaths from cancer in Idaho": "تصنيف:وفيات السرطان في أيداهو",
    "Category:Deaths from cancer in India": "تصنيف:وفيات السرطان في الهند",
    "Category:Deaths from cancer in Indiana": "تصنيف:وفيات السرطان في إنديانا",
    "Category:Deaths from cancer in Indonesia": "تصنيف:وفيات السرطان في إندونيسيا",
    "Category:Deaths from cancer in Iowa": "تصنيف:وفيات السرطان في آيوا",
    "Category:Deaths from cancer in Iran": "تصنيف:وفيات السرطان في إيران",
    "Category:Deaths from cancer in Iraq": "تصنيف:وفيات السرطان في العراق",
    "Category:Deaths from cancer in Ireland": "تصنيف:وفيات السرطان في أيرلندا",
    "Category:Deaths from cancer in Israel": "تصنيف:وفيات السرطان في إسرائيل",
    "Category:Deaths from cancer in Italy by region": "تصنيف:وفيات السرطان في إيطاليا حسب المنطقة",
    "Category:Deaths from cancer in Italy": "تصنيف:وفيات السرطان في إيطاليا",
    "Category:Deaths from cancer in Ivory Coast": "تصنيف:وفيات السرطان في ساحل العاج",
    "Category:Deaths from cancer in Jamaica": "تصنيف:وفيات السرطان في جامايكا",
    "Category:Deaths from cancer in Japan": "تصنيف:وفيات السرطان في اليابان",
    "Category:Deaths from cancer in Jordan": "تصنيف:وفيات السرطان في الأردن",
    "Category:Deaths from cancer in Kansas": "تصنيف:وفيات السرطان في كانساس",
    "Category:Deaths from cancer in Kazakhstan": "تصنيف:وفيات السرطان في كازاخستان",
    "Category:Deaths from cancer in Kentucky": "تصنيف:وفيات السرطان في كنتاكي",
    "Category:Deaths from cancer in Kenya": "تصنيف:وفيات السرطان في كينيا",
    "Category:Deaths from cancer in Korea": "تصنيف:وفيات السرطان في كوريا",
    "Category:Deaths from cancer in Kosovo": "تصنيف:وفيات السرطان في كوسوفو",
    "Category:Deaths from cancer in Latvia": "تصنيف:وفيات السرطان في لاتفيا",
    "Category:Deaths from cancer in Lazio": "تصنيف:وفيات السرطان في لاتسيو",
    "Category:Deaths from cancer in Lebanon": "تصنيف:وفيات السرطان في لبنان",
    "Category:Deaths from cancer in Libya": "تصنيف:وفيات السرطان في ليبيا",
    "Category:Deaths from cancer in Liguria": "تصنيف:وفيات السرطان في ليغوريا",
    "Category:Deaths from cancer in Lithuania": "تصنيف:وفيات السرطان في ليتوانيا",
    "Category:Deaths from cancer in Lombardy": "تصنيف:وفيات السرطان في لومبارديا",
    "Category:Deaths from cancer in Louisiana": "تصنيف:وفيات السرطان في لويزيانا",
    "Category:Deaths from cancer in Luxembourg": "تصنيف:وفيات السرطان في لوكسمبورغ",
    "Category:Deaths from cancer in Maine": "تصنيف:وفيات السرطان في مين",
    "Category:Deaths from cancer in Malaysia": "تصنيف:وفيات السرطان في ماليزيا",
    "Category:Deaths from cancer in Mali": "تصنيف:وفيات السرطان في مالي",
    "Category:Deaths from cancer in Manitoba": "تصنيف:وفيات السرطان في مانيتوبا",
    "Category:Deaths from cancer in Maranhão": "تصنيف:وفيات السرطان في مارانهاو",
    "Category:Deaths from cancer in Maryland": "تصنيف:وفيات السرطان في ماريلند",
    "Category:Deaths from cancer in Mexico": "تصنيف:وفيات السرطان في المكسيك",
    "Category:Deaths from cancer in Michigan": "تصنيف:وفيات السرطان في ميشيغان",
    "Category:Deaths from cancer in Minas Gerais": "تصنيف:وفيات السرطان في ميناس جيرايس",
    "Category:Deaths from cancer in Mississippi": "تصنيف:وفيات السرطان في مسيسيبي",
    "Category:Deaths from cancer in Montana": "تصنيف:وفيات السرطان في مونتانا",
    "Category:Deaths from cancer in Montenegro": "تصنيف:وفيات السرطان في الجبل الأسود",
    "Category:Deaths from cancer in Morocco": "تصنيف:وفيات السرطان في المغرب",
    "Category:Deaths from cancer in Myanmar": "تصنيف:وفيات السرطان في ميانمار",
    "Category:Deaths from cancer in Namibia": "تصنيف:وفيات السرطان في ناميبيا",
    "Category:Deaths from cancer in Nebraska": "تصنيف:وفيات السرطان في نبراسكا",
    "Category:Deaths from cancer in Nepal": "تصنيف:وفيات السرطان في نيبال",
    "Category:Deaths from cancer in Nevada": "تصنيف:وفيات السرطان في نيفادا",
    "Category:Deaths from cancer in New Brunswick": "تصنيف:وفيات السرطان في نيو برونزويك",
    "Category:Deaths from cancer in New Hampshire": "تصنيف:وفيات السرطان في نيوهامشير",
    "Category:Deaths from cancer in New Mexico": "تصنيف:وفيات السرطان في نيومكسيكو",
    "Category:Deaths from cancer in New Zealand": "تصنيف:وفيات السرطان في نيوزيلندا",
    "Category:Deaths from cancer in Newfoundland and Labrador": "تصنيف:وفيات السرطان في نيوفاوندلاند واللابرادور",
    "Category:Deaths from cancer in Nicaragua": "تصنيف:وفيات السرطان في نيكاراغوا",
    "Category:Deaths from cancer in Nigeria": "تصنيف:وفيات السرطان في نيجيريا",
    "Category:Deaths from cancer in North Dakota": "تصنيف:وفيات السرطان في داكوتا الشمالية",
    "Category:Deaths from cancer in Northern Ireland": "تصنيف:وفيات السرطان في أيرلندا الشمالية",
    "Category:Deaths from cancer in Norway": "تصنيف:وفيات السرطان في النرويج",
    "Category:Deaths from cancer in Nova Scotia": "تصنيف:وفيات السرطان في نوفا سكوشا",
    "Category:Deaths from cancer in Ohio": "تصنيف:وفيات السرطان في أوهايو",
    "Category:Deaths from cancer in Oklahoma": "تصنيف:وفيات السرطان في أوكلاهوما",
    "Category:Deaths from cancer in Oman": "تصنيف:وفيات السرطان في سلطنة عمان",
    "Category:Deaths from cancer in Ontario": "تصنيف:وفيات السرطان في أونتاريو",
    "Category:Deaths from cancer in Pakistan": "تصنيف:وفيات السرطان في باكستان",
    "Category:Deaths from cancer in Palestine": "تصنيف:وفيات السرطان في فلسطين",
    "Category:Deaths from cancer in Panama": "تصنيف:وفيات السرطان في بنما",
    "Category:Deaths from cancer in Papua New Guinea": "تصنيف:وفيات السرطان في بابوا غينيا الجديدة",
    "Category:Deaths from cancer in Paraguay": "تصنيف:وفيات السرطان في باراغواي",
    "Category:Deaths from cancer in Pennsylvania": "تصنيف:وفيات السرطان في بنسلفانيا",
    "Category:Deaths from cancer in Pernambuco": "تصنيف:وفيات السرطان في بيرنامبوكو",
    "Category:Deaths from cancer in Peru": "تصنيف:وفيات السرطان في بيرو",
    "Category:Deaths from cancer in Piedmont": "تصنيف:وفيات السرطان في بييمونتي",
    "Category:Deaths from cancer in Poland": "تصنيف:وفيات السرطان في بولندا",
    "Category:Deaths from cancer in Portugal": "تصنيف:وفيات السرطان في البرتغال",
    "Category:Deaths from cancer in Prince Edward Island": "تصنيف:وفيات السرطان في جزيرة الأمير إدوارد",
    "Category:Deaths from cancer in Puerto Rico": "تصنيف:وفيات السرطان في بورتوريكو",
    "Category:Deaths from cancer in Queensland": "تصنيف:وفيات السرطان في كوينزلاند",
    "Category:Deaths from cancer in Rio de Janeiro (state)": "تصنيف:وفيات السرطان في ولاية ريو دي جانيرو",
    "Category:Deaths from cancer in Rio Grande do Norte": "تصنيف:وفيات السرطان في ريو غراندي دو نورتي",
    "Category:Deaths from cancer in Rio Grande do Sul": "تصنيف:وفيات السرطان في ريو غراندي دو سول",
    "Category:Deaths from cancer in Romania": "تصنيف:وفيات السرطان في رومانيا",
    "Category:Deaths from cancer in Russia": "تصنيف:وفيات السرطان في روسيا",
    "Category:Deaths from cancer in Saint Kitts and Nevis": "تصنيف:وفيات السرطان في سانت كيتس ونيفيس",
    "Category:Deaths from cancer in Santa Catarina (state)": "تصنيف:وفيات السرطان في ولاية سانتا كاتارينا",
    "Category:Deaths from cancer in Saskatchewan": "تصنيف:وفيات السرطان في ساسكاتشوان",
    "Category:Deaths from cancer in Saudi Arabia": "تصنيف:وفيات السرطان في السعودية",
    "Category:Deaths from cancer in Scotland": "تصنيف:وفيات السرطان في إسكتلندا",
    "Category:Deaths from cancer in Serbia": "تصنيف:وفيات السرطان في صربيا",
    "Category:Deaths from cancer in Sergipe": "تصنيف:وفيات السرطان في سيرجيبي",
    "Category:Deaths from cancer in Sicily": "تصنيف:وفيات السرطان في صقلية",
    "Category:Deaths from cancer in Singapore": "تصنيف:وفيات السرطان في سنغافورة",
    "Category:Deaths from cancer in Slovenia": "تصنيف:وفيات السرطان في سلوفينيا",
    "Category:Deaths from cancer in South Australia": "تصنيف:وفيات السرطان في جنوب أستراليا",
    "Category:Deaths from cancer in South Dakota": "تصنيف:وفيات السرطان في داكوتا الجنوبية",
    "Category:Deaths from cancer in South Korea": "تصنيف:وفيات السرطان في كوريا الجنوبية",
    "Category:Deaths from cancer in Spain": "تصنيف:وفيات السرطان في إسبانيا",
    "Category:Deaths from cancer in Sri Lanka": "تصنيف:وفيات السرطان في سريلانكا",
    "Category:Deaths from cancer in Sweden": "تصنيف:وفيات السرطان في السويد",
    "Category:Deaths from cancer in Switzerland": "تصنيف:وفيات السرطان في سويسرا",
    "Category:Deaths from cancer in Syria": "تصنيف:وفيات السرطان في سوريا",
    "Category:Deaths from cancer in São Paulo (state)": "تصنيف:وفيات السرطان في ولاية ساو باولو",
    "Category:Deaths from cancer in Taiwan": "تصنيف:وفيات السرطان في تايوان",
    "Category:Deaths from cancer in Tajikistan": "تصنيف:وفيات السرطان في طاجيكستان",
    "Category:Deaths from cancer in Tanzania": "تصنيف:وفيات السرطان في تنزانيا",
    "Category:Deaths from cancer in Tasmania": "تصنيف:وفيات السرطان في تسمانيا",
    "Category:Deaths from cancer in Tennessee": "تصنيف:وفيات السرطان في تينيسي",
    "Category:Deaths from cancer in Texas": "تصنيف:وفيات السرطان في تكساس",
    "Category:Deaths from cancer in Thailand": "تصنيف:وفيات السرطان في تايلاند",
    "Category:Deaths from cancer in the Australian Capital Territory": "تصنيف:وفيات السرطان في إقليم العاصمة الأسترالية",
    "Category:Deaths from cancer in the Bahamas": "تصنيف:وفيات السرطان في باهاماس",
    "Category:Deaths from cancer in the Cook Islands": "تصنيف:وفيات السرطان في جزر كوك",
    "Category:Deaths from cancer in the Czech Republic": "تصنيف:وفيات السرطان في التشيك",
    "Category:Deaths from cancer in the Dominican Republic": "تصنيف:وفيات السرطان في جمهورية الدومينيكان",
    "Category:Deaths from cancer in the Federal District (Brazil)": "تصنيف:وفيات السرطان في القطاع الفدرالي (البرازيل)",
    "Category:Deaths from cancer in the Federated States of Micronesia": "تصنيف:وفيات السرطان في ولايات ميكرونيسيا المتحدة",
    "Category:Deaths from cancer in the Isle of Man": "تصنيف:وفيات السرطان في جزيرة مان",
    "Category:Deaths from cancer in the Netherlands": "تصنيف:وفيات السرطان في هولندا",
    "Category:Deaths from cancer in the People's Republic of China": "تصنيف:وفيات السرطان في جمهورية الصين الشعبية",
    "Category:Deaths from cancer in the Philippines": "تصنيف:وفيات السرطان في الفلبين",
    "Category:Deaths from cancer in the Republic of Ireland": "تصنيف:وفيات السرطان في جمهورية أيرلندا",
    "Category:Deaths from cancer in the Russian Empire": "تصنيف:وفيات السرطان في الإمبراطورية الروسية",
    "Category:Deaths from cancer in the Soviet Union": "تصنيف:وفيات السرطان في الاتحاد السوفيتي",
    "Category:Deaths from cancer in the United Arab Emirates": "تصنيف:وفيات السرطان في الإمارات العربية المتحدة",
    "Category:Deaths from cancer in the United Kingdom": "تصنيف:وفيات السرطان في المملكة المتحدة",
    "Category:Deaths from cancer in the United States by state": "تصنيف:وفيات السرطان في الولايات المتحدة حسب الولاية",
    "Category:Deaths from cancer in the United States Virgin Islands": "تصنيف:وفيات السرطان في جزر العذراء الأمريكية",
    "Category:Deaths from cancer in the United States": "تصنيف:وفيات السرطان في الولايات المتحدة",
    "Category:Deaths from cancer in Tunisia": "تصنيف:وفيات السرطان في تونس",
    "Category:Deaths from cancer in Turkey": "تصنيف:وفيات السرطان في تركيا",
    "Category:Deaths from cancer in Tuscany": "تصنيف:وفيات السرطان في توسكانا",
    "Category:Deaths from cancer in Ukraine": "تصنيف:وفيات السرطان في أوكرانيا",
    "Category:Deaths from cancer in Umbria": "تصنيف:وفيات السرطان في أومبريا",
    "Category:Deaths from cancer in Utah": "تصنيف:وفيات السرطان في يوتا",
    "Category:Deaths from cancer in Vanuatu": "تصنيف:وفيات السرطان في فانواتو",
    "Category:Deaths from cancer in Veneto": "تصنيف:وفيات السرطان في فينيتو",
    "Category:Deaths from cancer in Venezuela": "تصنيف:وفيات السرطان في فنزويلا",
    "Category:Deaths from cancer in Vermont": "تصنيف:وفيات السرطان في فيرمونت",
    "Category:Deaths from cancer in Virginia": "تصنيف:وفيات السرطان في فرجينيا",
    "Category:Deaths from cancer in Wales": "تصنيف:وفيات السرطان في ويلز",
    "Category:Deaths from cancer in Washington, D.C.": "تصنيف:وفيات السرطان في واشنطن العاصمة",
    "Category:Deaths from cancer in Western Australia": "تصنيف:وفيات السرطان في أستراليا الغربية",
    "Category:Deaths from cancer in Wisconsin": "تصنيف:وفيات السرطان في ويسكونسن",
    "Category:Deaths from cancer in Wyoming": "تصنيف:وفيات السرطان في وايومنغ",
    "Category:Deaths from cancer in Yemen": "تصنيف:وفيات السرطان في اليمن",
    "Category:Deaths from cancer in Yugoslavia": "تصنيف:وفيات السرطان في يوغسلافيا",
    "Category:Deaths from cancer in Yukon": "تصنيف:وفيات السرطان في يوكون",
    "Category:Deaths from cancer in Zambia": "تصنيف:وفيات السرطان في زامبيا",
    "Category:Deaths from cancer in Zimbabwe": "تصنيف:وفيات السرطان في زيمبابوي",
    "Category:Deaths from chronic lymphocytic leukemia": "تصنيف:وفيات من ابيضاض الدم الليمفاوي المزمن",
    "Category:Deaths from fire in Japan": "تصنيف:وفيات ناجمة عن الحريق في اليابان",
    "Category:Deaths from fire in the United States": "تصنيف:وفيات ناجمة عن الحريق في الولايات المتحدة",
    "Category:Deaths from fire": "تصنيف:وفيات ناجمة عن الحريق",
    "Category:Deaths from lightning strikes": "تصنيف:وفيات من ضربات البرق",
    "Category:Deaths from lung cancer by country subdivision": "تصنيف:وفيات سرطان الرئة حسب تقسيم البلد",
    "Category:Deaths from lung cancer by country": "تصنيف:وفيات سرطان الرئة حسب البلد",
    "Category:Deaths from lung cancer by former country": "تصنيف:وفيات سرطان الرئة حسب البلد السابق",
    "Category:Deaths from lung cancer in Alabama": "تصنيف:وفيات سرطان الرئة في ألاباما",
    "Category:Deaths from lung cancer in Algeria": "تصنيف:وفيات سرطان الرئة في الجزائر",
    "Category:Deaths from lung cancer in Argentina": "تصنيف:وفيات سرطان الرئة في الأرجنتين",
    "Category:Deaths from lung cancer in Arizona": "تصنيف:وفيات سرطان الرئة في أريزونا",
    "Category:Deaths from lung cancer in Arkansas": "تصنيف:وفيات سرطان الرئة في أركنساس",
    "Category:Deaths from lung cancer in Australia": "تصنيف:وفيات سرطان الرئة في أستراليا",
    "Category:Deaths from lung cancer in Austria": "تصنيف:وفيات سرطان الرئة في النمسا",
    "Category:Deaths from lung cancer in Belgium": "تصنيف:وفيات سرطان الرئة في بلجيكا",
    "Category:Deaths from lung cancer in Bolivia": "تصنيف:وفيات سرطان الرئة في بوليفيا",
    "Category:Deaths from lung cancer in Brazil": "تصنيف:وفيات سرطان الرئة في البرازيل",
    "Category:Deaths from lung cancer in Calabria": "تصنيف:وفيات سرطان الرئة في كالابريا",
    "Category:Deaths from lung cancer in California": "تصنيف:وفيات سرطان الرئة في كاليفورنيا",
    "Category:Deaths from lung cancer in Chile": "تصنيف:وفيات سرطان الرئة في تشيلي",
    "Category:Deaths from lung cancer in China": "تصنيف:وفيات سرطان الرئة في الصين",
    "Category:Deaths from lung cancer in Colorado": "تصنيف:وفيات سرطان الرئة في كولورادو",
    "Category:Deaths from lung cancer in Connecticut": "تصنيف:وفيات سرطان الرئة في كونيتيكت",
    "Category:Deaths from lung cancer in Croatia": "تصنيف:وفيات سرطان الرئة في كرواتيا",
    "Category:Deaths from lung cancer in Cuba": "تصنيف:وفيات سرطان الرئة في كوبا",
    "Category:Deaths from lung cancer in Denmark": "تصنيف:وفيات سرطان الرئة في الدنمارك",
    "Category:Deaths from lung cancer in Ecuador": "تصنيف:وفيات سرطان الرئة في الإكوادور",
    "Category:Deaths from lung cancer in Egypt": "تصنيف:وفيات سرطان الرئة في مصر",
    "Category:Deaths from lung cancer in England": "تصنيف:وفيات سرطان الرئة في إنجلترا",
    "Category:Deaths from lung cancer in Florida": "تصنيف:وفيات سرطان الرئة في فلوريدا",
    "Category:Deaths from lung cancer in France": "تصنيف:وفيات سرطان الرئة في فرنسا",
    "Category:Deaths from lung cancer in Georgia (U.S. state)": "تصنيف:وفيات سرطان الرئة في ولاية جورجيا",
    "Category:Deaths from lung cancer in Germany": "تصنيف:وفيات سرطان الرئة في ألمانيا",
    "Category:Deaths from lung cancer in Greece": "تصنيف:وفيات سرطان الرئة في اليونان",
    "Category:Deaths from lung cancer in Hawaii": "تصنيف:وفيات سرطان الرئة في هاواي",
    "Category:Deaths from lung cancer in Hong Kong": "تصنيف:وفيات سرطان الرئة في هونغ كونغ",
    "Category:Deaths from lung cancer in Idaho": "تصنيف:وفيات سرطان الرئة في أيداهو",
    "Category:Deaths from lung cancer in Illinois": "تصنيف:وفيات سرطان الرئة في إلينوي",
    "Category:Deaths from lung cancer in India": "تصنيف:وفيات سرطان الرئة في الهند",
    "Category:Deaths from lung cancer in Indiana": "تصنيف:وفيات سرطان الرئة في إنديانا",
    "Category:Deaths from lung cancer in Indonesia": "تصنيف:وفيات سرطان الرئة في إندونيسيا",
    "Category:Deaths from lung cancer in Iowa": "تصنيف:وفيات سرطان الرئة في آيوا",
    "Category:Deaths from lung cancer in Iran": "تصنيف:وفيات سرطان الرئة في إيران",
    "Category:Deaths from lung cancer in Ireland": "تصنيف:وفيات سرطان الرئة في أيرلندا",
    "Category:Deaths from lung cancer in Italy by region": "تصنيف:وفيات سرطان الرئة في إيطاليا حسب المنطقة",
    "Category:Deaths from lung cancer in Italy": "تصنيف:وفيات سرطان الرئة في إيطاليا",
    "Category:Deaths from lung cancer in Japan": "تصنيف:وفيات سرطان الرئة في اليابان",
    "Category:Deaths from lung cancer in Kansas": "تصنيف:وفيات سرطان الرئة في كانساس",
    "Category:Deaths from lung cancer in Kentucky": "تصنيف:وفيات سرطان الرئة في كنتاكي",
    "Category:Deaths from lung cancer in Lazio": "تصنيف:وفيات سرطان الرئة في لاتسيو",
    "Category:Deaths from lung cancer in Lombardy": "تصنيف:وفيات سرطان الرئة في لومبارديا",
    "Category:Deaths from lung cancer in Louisiana": "تصنيف:وفيات سرطان الرئة في لويزيانا",
    "Category:Deaths from lung cancer in Luxembourg": "تصنيف:وفيات سرطان الرئة في لوكسمبورغ",
    "Category:Deaths from lung cancer in Maine": "تصنيف:وفيات سرطان الرئة في مين",
    "Category:Deaths from lung cancer in Malaysia": "تصنيف:وفيات سرطان الرئة في ماليزيا",
    "Category:Deaths from lung cancer in Maryland": "تصنيف:وفيات سرطان الرئة في ماريلند",
    "Category:Deaths from lung cancer in Massachusetts": "تصنيف:وفيات سرطان الرئة في ماساتشوستس",
    "Category:Deaths from lung cancer in Mexico": "تصنيف:وفيات سرطان الرئة في المكسيك",
    "Category:Deaths from lung cancer in Michigan": "تصنيف:وفيات سرطان الرئة في ميشيغان",
    "Category:Deaths from lung cancer in Missouri": "تصنيف:وفيات سرطان الرئة في ميزوري",
    "Category:Deaths from lung cancer in Morocco": "تصنيف:وفيات سرطان الرئة في المغرب",
    "Category:Deaths from lung cancer in Myanmar": "تصنيف:وفيات سرطان الرئة في ميانمار",
    "Category:Deaths from lung cancer in Nevada": "تصنيف:وفيات سرطان الرئة في نيفادا",
    "Category:Deaths from lung cancer in New Hampshire": "تصنيف:وفيات سرطان الرئة في نيوهامشير",
    "Category:Deaths from lung cancer in New Jersey": "تصنيف:وفيات سرطان الرئة في نيوجيرسي",
    "Category:Deaths from lung cancer in New York (state)": "تصنيف:وفيات سرطان الرئة في ولاية نيويورك",
    "Category:Deaths from lung cancer in New Zealand": "تصنيف:وفيات سرطان الرئة في نيوزيلندا",
    "Category:Deaths from lung cancer in North Carolina": "تصنيف:وفيات سرطان الرئة في كارولاينا الشمالية",
    "Category:Deaths from lung cancer in Northern Ireland": "تصنيف:وفيات سرطان الرئة في أيرلندا الشمالية",
    "Category:Deaths from lung cancer in Norway": "تصنيف:وفيات سرطان الرئة في النرويج",
    "Category:Deaths from lung cancer in Ohio": "تصنيف:وفيات سرطان الرئة في أوهايو",
    "Category:Deaths from lung cancer in Oklahoma": "تصنيف:وفيات سرطان الرئة في أوكلاهوما",
    "Category:Deaths from lung cancer in Pakistan": "تصنيف:وفيات سرطان الرئة في باكستان",
    "Category:Deaths from lung cancer in Pennsylvania": "تصنيف:وفيات سرطان الرئة في بنسلفانيا",
    "Category:Deaths from lung cancer in Peru": "تصنيف:وفيات سرطان الرئة في بيرو",
    "Category:Deaths from lung cancer in Piedmont": "تصنيف:وفيات سرطان الرئة في بييمونتي",
    "Category:Deaths from lung cancer in Poland": "تصنيف:وفيات سرطان الرئة في بولندا",
    "Category:Deaths from lung cancer in Portugal": "تصنيف:وفيات سرطان الرئة في البرتغال",
    "Category:Deaths from lung cancer in Puerto Rico": "تصنيف:وفيات سرطان الرئة في بورتوريكو",
    "Category:Deaths from lung cancer in Romania": "تصنيف:وفيات سرطان الرئة في رومانيا",
    "Category:Deaths from lung cancer in Russia": "تصنيف:وفيات سرطان الرئة في روسيا",
    "Category:Deaths from lung cancer in Scotland": "تصنيف:وفيات سرطان الرئة في إسكتلندا",
    "Category:Deaths from lung cancer in Serbia": "تصنيف:وفيات سرطان الرئة في صربيا",
    "Category:Deaths from lung cancer in Singapore": "تصنيف:وفيات سرطان الرئة في سنغافورة",
    "Category:Deaths from lung cancer in South Carolina": "تصنيف:وفيات سرطان الرئة في كارولاينا الجنوبية",
    "Category:Deaths from lung cancer in South Korea": "تصنيف:وفيات سرطان الرئة في كوريا الجنوبية",
    "Category:Deaths from lung cancer in Spain": "تصنيف:وفيات سرطان الرئة في إسبانيا",
    "Category:Deaths from lung cancer in Sweden": "تصنيف:وفيات سرطان الرئة في السويد",
    "Category:Deaths from lung cancer in Switzerland": "تصنيف:وفيات سرطان الرئة في سويسرا",
    "Category:Deaths from lung cancer in Taiwan": "تصنيف:وفيات سرطان الرئة في تايوان",
    "Category:Deaths from lung cancer in Tennessee": "تصنيف:وفيات سرطان الرئة في تينيسي",
    "Category:Deaths from lung cancer in Texas": "تصنيف:وفيات سرطان الرئة في تكساس",
    "Category:Deaths from lung cancer in the Czech Republic": "تصنيف:وفيات سرطان الرئة في التشيك",
    "Category:Deaths from lung cancer in the Netherlands": "تصنيف:وفيات سرطان الرئة في هولندا",
    "Category:Deaths from lung cancer in the People's Republic of China": "تصنيف:وفيات سرطان الرئة في جمهورية الصين الشعبية",
    "Category:Deaths from lung cancer in the Philippines": "تصنيف:وفيات سرطان الرئة في الفلبين",
    "Category:Deaths from lung cancer in the Republic of Ireland": "تصنيف:وفيات سرطان الرئة في جمهورية أيرلندا",
    "Category:Deaths from lung cancer in the Soviet Union": "تصنيف:وفيات سرطان الرئة في الاتحاد السوفيتي",
    "Category:Deaths from lung cancer in the United Kingdom": "تصنيف:وفيات سرطان الرئة في المملكة المتحدة",
    "Category:Deaths from lung cancer in the United States by state": "تصنيف:وفيات سرطان الرئة في الولايات المتحدة حسب الولاية",
    "Category:Deaths from lung cancer in the United States": "تصنيف:وفيات سرطان الرئة في الولايات المتحدة",
    "Category:Deaths from lung cancer in Turkey": "تصنيف:وفيات سرطان الرئة في تركيا",
    "Category:Deaths from lung cancer in Tuscany": "تصنيف:وفيات سرطان الرئة في توسكانا",
    "Category:Deaths from lung cancer in Umbria": "تصنيف:وفيات سرطان الرئة في أومبريا",
    "Category:Deaths from lung cancer in Vermont": "تصنيف:وفيات سرطان الرئة في فيرمونت",
    "Category:Deaths from lung cancer in Virginia": "تصنيف:وفيات سرطان الرئة في فرجينيا",
    "Category:Deaths from lung cancer in Wales": "تصنيف:وفيات سرطان الرئة في ويلز",
    "Category:Deaths from lung cancer in Washington (state)": "تصنيف:وفيات سرطان الرئة في ولاية واشنطن",
    "Category:Deaths from lung cancer in Washington, D.C.": "تصنيف:وفيات سرطان الرئة في واشنطن العاصمة",
    "Category:Deaths from lung cancer in Yugoslavia": "تصنيف:وفيات سرطان الرئة في يوغسلافيا",
    "Category:Deaths from medical malpractice": "تصنيف:وفيات من خطأ طبي",
    "Category:Deaths from mesothelioma in Australia": "تصنيف:وفيات من ورم المتوسطة في أستراليا",
    "Category:Deaths from mesothelioma in the United States": "تصنيف:وفيات من ورم المتوسطة في الولايات المتحدة",
    "Category:Deaths from pneumonia by country subdivision": "تصنيف:وفيات الالتهاب الرئوي حسب تقسيم البلد",
    "Category:Deaths from pneumonia by country": "تصنيف:وفيات الالتهاب الرئوي حسب البلد",
    "Category:Deaths from pneumonia by former country": "تصنيف:وفيات الالتهاب الرئوي حسب البلد السابق",
    "Category:Deaths from pneumonia in Alabama": "تصنيف:وفيات الالتهاب الرئوي في ألاباما",
    "Category:Deaths from pneumonia in Alaska": "تصنيف:وفيات الالتهاب الرئوي في ألاسكا",
    "Category:Deaths from pneumonia in Alberta": "تصنيف:وفيات الالتهاب الرئوي في ألبرتا",
    "Category:Deaths from pneumonia in Algeria": "تصنيف:وفيات الالتهاب الرئوي في الجزائر",
    "Category:Deaths from pneumonia in Argentina": "تصنيف:وفيات الالتهاب الرئوي في الأرجنتين",
    "Category:Deaths from pneumonia in Arizona": "تصنيف:وفيات الالتهاب الرئوي في أريزونا",
    "Category:Deaths from pneumonia in Arkansas": "تصنيف:وفيات الالتهاب الرئوي في أركنساس",
    "Category:Deaths from pneumonia in Australia by state or territory": "تصنيف:وفيات الالتهاب الرئوي في أستراليا حسب الولاية أو الإقليم",
    "Category:Deaths from pneumonia in Australia": "تصنيف:وفيات الالتهاب الرئوي في أستراليا",
    "Category:Deaths from pneumonia in Austria": "تصنيف:وفيات الالتهاب الرئوي في النمسا",
    "Category:Deaths from pneumonia in Austria-Hungary": "تصنيف:وفيات الالتهاب الرئوي في الإمبراطورية النمساوية المجرية",
    "Category:Deaths from pneumonia in Bangladesh": "تصنيف:وفيات الالتهاب الرئوي في بنغلاديش",
    "Category:Deaths from pneumonia in Brazil by state": "تصنيف:وفيات الالتهاب الرئوي في البرازيل حسب الولاية",
    "Category:Deaths from pneumonia in Brazil": "تصنيف:وفيات الالتهاب الرئوي في البرازيل",
    "Category:Deaths from pneumonia in British Columbia": "تصنيف:وفيات الالتهاب الرئوي في كولومبيا البريطانية",
    "Category:Deaths from pneumonia in Bulgaria": "تصنيف:وفيات الالتهاب الرئوي في بلغاريا",
    "Category:Deaths from pneumonia in California": "تصنيف:وفيات الالتهاب الرئوي في كاليفورنيا",
    "Category:Deaths from pneumonia in Campania": "تصنيف:وفيات الالتهاب الرئوي في كامبانيا",
    "Category:Deaths from pneumonia in Canada": "تصنيف:وفيات الالتهاب الرئوي في كندا",
    "Category:Deaths from pneumonia in Chile": "تصنيف:وفيات الالتهاب الرئوي في تشيلي",
    "Category:Deaths from pneumonia in China": "تصنيف:وفيات الالتهاب الرئوي في الصين",
    "Category:Deaths from pneumonia in Colombia": "تصنيف:وفيات الالتهاب الرئوي في كولومبيا",
    "Category:Deaths from pneumonia in Colorado": "تصنيف:وفيات الالتهاب الرئوي في كولورادو",
    "Category:Deaths from pneumonia in Connecticut": "تصنيف:وفيات الالتهاب الرئوي في كونيتيكت",
    "Category:Deaths from pneumonia in Croatia": "تصنيف:وفيات الالتهاب الرئوي في كرواتيا",
    "Category:Deaths from pneumonia in Cyprus": "تصنيف:وفيات الالتهاب الرئوي في قبرص",
    "Category:Deaths from pneumonia in Denmark": "تصنيف:وفيات الالتهاب الرئوي في الدنمارك",
    "Category:Deaths from pneumonia in Ecuador": "تصنيف:وفيات الالتهاب الرئوي في الإكوادور",
    "Category:Deaths from pneumonia in Egypt": "تصنيف:وفيات الالتهاب الرئوي في مصر",
    "Category:Deaths from pneumonia in England": "تصنيف:وفيات الالتهاب الرئوي في إنجلترا",
    "Category:Deaths from pneumonia in Finland": "تصنيف:وفيات الالتهاب الرئوي في فنلندا",
    "Category:Deaths from pneumonia in Florida": "تصنيف:وفيات الالتهاب الرئوي في فلوريدا",
    "Category:Deaths from pneumonia in France": "تصنيف:وفيات الالتهاب الرئوي في فرنسا",
    "Category:Deaths from pneumonia in Gabon": "تصنيف:وفيات الالتهاب الرئوي في الغابون",
    "Category:Deaths from pneumonia in Germany": "تصنيف:وفيات الالتهاب الرئوي في ألمانيا",
    "Category:Deaths from pneumonia in Ghana": "تصنيف:وفيات الالتهاب الرئوي في غانا",
    "Category:Deaths from pneumonia in Guatemala": "تصنيف:وفيات الالتهاب الرئوي في غواتيمالا",
    "Category:Deaths from pneumonia in Hawaii": "تصنيف:وفيات الالتهاب الرئوي في هاواي",
    "Category:Deaths from pneumonia in Honduras": "تصنيف:وفيات الالتهاب الرئوي في هندوراس",
    "Category:Deaths from pneumonia in Hungary": "تصنيف:وفيات الالتهاب الرئوي في المجر",
    "Category:Deaths from pneumonia in Idaho": "تصنيف:وفيات الالتهاب الرئوي في أيداهو",
    "Category:Deaths from pneumonia in Illinois": "تصنيف:وفيات الالتهاب الرئوي في إلينوي",
    "Category:Deaths from pneumonia in India": "تصنيف:وفيات الالتهاب الرئوي في الهند",
    "Category:Deaths from pneumonia in Indiana": "تصنيف:وفيات الالتهاب الرئوي في إنديانا",
    "Category:Deaths from pneumonia in Indonesia": "تصنيف:وفيات الالتهاب الرئوي في إندونيسيا",
    "Category:Deaths from pneumonia in Iowa": "تصنيف:وفيات الالتهاب الرئوي في آيوا",
    "Category:Deaths from pneumonia in Iran": "تصنيف:وفيات الالتهاب الرئوي في إيران",
    "Category:Deaths from pneumonia in Ireland": "تصنيف:وفيات الالتهاب الرئوي في أيرلندا",
    "Category:Deaths from pneumonia in Italy by region": "تصنيف:وفيات الالتهاب الرئوي في إيطاليا حسب المنطقة",
    "Category:Deaths from pneumonia in Italy": "تصنيف:وفيات الالتهاب الرئوي في إيطاليا",
    "Category:Deaths from pneumonia in Jamaica": "تصنيف:وفيات الالتهاب الرئوي في جامايكا",
    "Category:Deaths from pneumonia in Japan": "تصنيف:وفيات الالتهاب الرئوي في اليابان",
    "Category:Deaths from pneumonia in Kansas": "تصنيف:وفيات الالتهاب الرئوي في كانساس",
    "Category:Deaths from pneumonia in Kentucky": "تصنيف:وفيات الالتهاب الرئوي في كنتاكي",
    "Category:Deaths from pneumonia in Kenya": "تصنيف:وفيات الالتهاب الرئوي في كينيا",
    "Category:Deaths from pneumonia in Lazio": "تصنيف:وفيات الالتهاب الرئوي في لاتسيو",
    "Category:Deaths from pneumonia in Lebanon": "تصنيف:وفيات الالتهاب الرئوي في لبنان",
    "Category:Deaths from pneumonia in Liechtenstein": "تصنيف:وفيات الالتهاب الرئوي في ليختنشتاين",
    "Category:Deaths from pneumonia in Liguria": "تصنيف:وفيات الالتهاب الرئوي في ليغوريا",
    "Category:Deaths from pneumonia in Lombardy": "تصنيف:وفيات الالتهاب الرئوي في لومبارديا",
    "Category:Deaths from pneumonia in Louisiana": "تصنيف:وفيات الالتهاب الرئوي في لويزيانا",
    "Category:Deaths from pneumonia in Maine": "تصنيف:وفيات الالتهاب الرئوي في مين",
    "Category:Deaths from pneumonia in Malaysia": "تصنيف:وفيات الالتهاب الرئوي في ماليزيا",
    "Category:Deaths from pneumonia in Maryland": "تصنيف:وفيات الالتهاب الرئوي في ماريلند",
    "Category:Deaths from pneumonia in Mexico": "تصنيف:وفيات الالتهاب الرئوي في المكسيك",
    "Category:Deaths from pneumonia in Mississippi": "تصنيف:وفيات الالتهاب الرئوي في مسيسيبي",
    "Category:Deaths from pneumonia in Missouri": "تصنيف:وفيات الالتهاب الرئوي في ميزوري",
    "Category:Deaths from pneumonia in Monaco": "تصنيف:وفيات الالتهاب الرئوي في موناكو",
    "Category:Deaths from pneumonia in Montana": "تصنيف:وفيات الالتهاب الرئوي في مونتانا",
    "Category:Deaths from pneumonia in Nebraska": "تصنيف:وفيات الالتهاب الرئوي في نبراسكا",
    "Category:Deaths from pneumonia in Nepal": "تصنيف:وفيات الالتهاب الرئوي في نيبال",
    "Category:Deaths from pneumonia in Nevada": "تصنيف:وفيات الالتهاب الرئوي في نيفادا",
    "Category:Deaths from pneumonia in New Hampshire": "تصنيف:وفيات الالتهاب الرئوي في نيوهامشير",
    "Category:Deaths from pneumonia in New Jersey": "تصنيف:وفيات الالتهاب الرئوي في نيوجيرسي",
    "Category:Deaths from pneumonia in New Mexico": "تصنيف:وفيات الالتهاب الرئوي في نيومكسيكو",
    "Category:Deaths from pneumonia in New York (state)": "تصنيف:وفيات الالتهاب الرئوي في ولاية نيويورك",
    "Category:Deaths from pneumonia in New York City": "تصنيف:وفيات الالتهاب الرئوي في مدينة نيويورك",
    "Category:Deaths from pneumonia in New Zealand": "تصنيف:وفيات الالتهاب الرئوي في نيوزيلندا",
    "Category:Deaths from pneumonia in Nigeria": "تصنيف:وفيات الالتهاب الرئوي في نيجيريا",
    "Category:Deaths from pneumonia in North Carolina": "تصنيف:وفيات الالتهاب الرئوي في كارولاينا الشمالية",
    "Category:Deaths from pneumonia in North Dakota": "تصنيف:وفيات الالتهاب الرئوي في داكوتا الشمالية",
    "Category:Deaths from pneumonia in Norway": "تصنيف:وفيات الالتهاب الرئوي في النرويج",
    "Category:Deaths from pneumonia in Nova Scotia": "تصنيف:وفيات الالتهاب الرئوي في نوفا سكوشا",
    "Category:Deaths from pneumonia in Ohio": "تصنيف:وفيات الالتهاب الرئوي في أوهايو",
    "Category:Deaths from pneumonia in Oklahoma": "تصنيف:وفيات الالتهاب الرئوي في أوكلاهوما",
    "Category:Deaths from pneumonia in Ontario": "تصنيف:وفيات الالتهاب الرئوي في أونتاريو",
    "Category:Deaths from pneumonia in Oregon": "تصنيف:وفيات الالتهاب الرئوي في أوريغن",
    "Category:Deaths from pneumonia in Pennsylvania": "تصنيف:وفيات الالتهاب الرئوي في بنسلفانيا",
    "Category:Deaths from pneumonia in Peru": "تصنيف:وفيات الالتهاب الرئوي في بيرو",
    "Category:Deaths from pneumonia in Piedmont": "تصنيف:وفيات الالتهاب الرئوي في بييمونتي",
    "Category:Deaths from pneumonia in Poland": "تصنيف:وفيات الالتهاب الرئوي في بولندا",
    "Category:Deaths from pneumonia in Portugal": "تصنيف:وفيات الالتهاب الرئوي في البرتغال",
    "Category:Deaths from pneumonia in Prince Edward Island": "تصنيف:وفيات الالتهاب الرئوي في جزيرة الأمير إدوارد",
    "Category:Deaths from pneumonia in Puerto Rico": "تصنيف:وفيات الالتهاب الرئوي في بورتوريكو",
    "Category:Deaths from pneumonia in Quebec": "تصنيف:وفيات الالتهاب الرئوي في كيبك",
    "Category:Deaths from pneumonia in Queensland": "تصنيف:وفيات الالتهاب الرئوي في كوينزلاند",
    "Category:Deaths from pneumonia in Rhode Island": "تصنيف:وفيات الالتهاب الرئوي في رود آيلاند",
    "Category:Deaths from pneumonia in Rio de Janeiro (state)": "تصنيف:وفيات الالتهاب الرئوي في ولاية ريو دي جانيرو",
    "Category:Deaths from pneumonia in Rio Grande do Sul": "تصنيف:وفيات الالتهاب الرئوي في ريو غراندي دو سول",
    "Category:Deaths from pneumonia in Romania": "تصنيف:وفيات الالتهاب الرئوي في رومانيا",
    "Category:Deaths from pneumonia in Russia": "تصنيف:وفيات الالتهاب الرئوي في روسيا",
    "Category:Deaths from pneumonia in Saint Kitts and Nevis": "تصنيف:وفيات الالتهاب الرئوي في سانت كيتس ونيفيس",
    "Category:Deaths from pneumonia in Saskatchewan": "تصنيف:وفيات الالتهاب الرئوي في ساسكاتشوان",
    "Category:Deaths from pneumonia in Saudi Arabia": "تصنيف:وفيات الالتهاب الرئوي في السعودية",
    "Category:Deaths from pneumonia in Scotland": "تصنيف:وفيات الالتهاب الرئوي في إسكتلندا",
    "Category:Deaths from pneumonia in Serbia": "تصنيف:وفيات الالتهاب الرئوي في صربيا",
    "Category:Deaths from pneumonia in Sicily": "تصنيف:وفيات الالتهاب الرئوي في صقلية",
    "Category:Deaths from pneumonia in Singapore": "تصنيف:وفيات الالتهاب الرئوي في سنغافورة",
    "Category:Deaths from pneumonia in South Australia": "تصنيف:وفيات الالتهاب الرئوي في جنوب أستراليا",
    "Category:Deaths from pneumonia in South Carolina": "تصنيف:وفيات الالتهاب الرئوي في كارولاينا الجنوبية",
    "Category:Deaths from pneumonia in South Dakota": "تصنيف:وفيات الالتهاب الرئوي في داكوتا الجنوبية",
    "Category:Deaths from pneumonia in South Korea": "تصنيف:وفيات الالتهاب الرئوي في كوريا الجنوبية",
    "Category:Deaths from pneumonia in Spain": "تصنيف:وفيات الالتهاب الرئوي في إسبانيا",
    "Category:Deaths from pneumonia in Sweden": "تصنيف:وفيات الالتهاب الرئوي في السويد",
    "Category:Deaths from pneumonia in Switzerland": "تصنيف:وفيات الالتهاب الرئوي في سويسرا",
    "Category:Deaths from pneumonia in São Paulo (state)": "تصنيف:وفيات الالتهاب الرئوي في ولاية ساو باولو",
    "Category:Deaths from pneumonia in Tasmania": "تصنيف:وفيات الالتهاب الرئوي في تسمانيا",
    "Category:Deaths from pneumonia in Texas": "تصنيف:وفيات الالتهاب الرئوي في تكساس",
    "Category:Deaths from pneumonia in the Dominican Republic": "تصنيف:وفيات الالتهاب الرئوي في جمهورية الدومينيكان",
    "Category:Deaths from pneumonia in the Netherlands": "تصنيف:وفيات الالتهاب الرئوي في هولندا",
    "Category:Deaths from pneumonia in the People's Republic of China": "تصنيف:وفيات الالتهاب الرئوي في جمهورية الصين الشعبية",
    "Category:Deaths from pneumonia in the Philippines": "تصنيف:وفيات الالتهاب الرئوي في الفلبين",
    "Category:Deaths from pneumonia in the Republic of Ireland": "تصنيف:وفيات الالتهاب الرئوي في جمهورية أيرلندا",
    "Category:Deaths from pneumonia in the Russian Empire": "تصنيف:وفيات الالتهاب الرئوي في الإمبراطورية الروسية",
    "Category:Deaths from pneumonia in the United Arab Emirates": "تصنيف:وفيات الالتهاب الرئوي في الإمارات العربية المتحدة",
    "Category:Deaths from pneumonia in the United Kingdom": "تصنيف:وفيات الالتهاب الرئوي في المملكة المتحدة",
    "Category:Deaths from pneumonia in the United States by state": "تصنيف:وفيات الالتهاب الرئوي في الولايات المتحدة حسب الولاية",
    "Category:Deaths from pneumonia in the United States": "تصنيف:وفيات الالتهاب الرئوي في الولايات المتحدة",
    "Category:Deaths from pneumonia in Turkey": "تصنيف:وفيات الالتهاب الرئوي في تركيا",
    "Category:Deaths from pneumonia in Tuscany": "تصنيف:وفيات الالتهاب الرئوي في توسكانا",
    "Category:Deaths from pneumonia in Ukraine": "تصنيف:وفيات الالتهاب الرئوي في أوكرانيا",
    "Category:Deaths from pneumonia in Umbria": "تصنيف:وفيات الالتهاب الرئوي في أومبريا",
    "Category:Deaths from pneumonia in Utah": "تصنيف:وفيات الالتهاب الرئوي في يوتا",
    "Category:Deaths from pneumonia in Vatican City": "تصنيف:وفيات الالتهاب الرئوي في الفاتيكان",
    "Category:Deaths from pneumonia in Veneto": "تصنيف:وفيات الالتهاب الرئوي في فينيتو",
    "Category:Deaths from pneumonia in Venezuela": "تصنيف:وفيات الالتهاب الرئوي في فنزويلا",
    "Category:Deaths from pneumonia in Vietnam": "تصنيف:وفيات الالتهاب الرئوي في فيتنام",
    "Category:Deaths from pneumonia in Virginia": "تصنيف:وفيات الالتهاب الرئوي في فرجينيا",
    "Category:Deaths from pneumonia in Wales": "تصنيف:وفيات الالتهاب الرئوي في ويلز",
    "Category:Deaths from pneumonia in Washington (state)": "تصنيف:وفيات الالتهاب الرئوي في ولاية واشنطن",
    "Category:Deaths from pneumonia in Washington, D.C.": "تصنيف:وفيات الالتهاب الرئوي في واشنطن العاصمة",
    "Category:Deaths from pneumonia in Western Australia": "تصنيف:وفيات الالتهاب الرئوي في أستراليا الغربية",
    "Category:Deaths from pneumonia in Wisconsin": "تصنيف:وفيات الالتهاب الرئوي في ويسكونسن",
    "Category:Deaths from pneumonia in Wyoming": "تصنيف:وفيات الالتهاب الرئوي في وايومنغ",
    "Category:Deaths from pneumonia in Zambia": "تصنيف:وفيات الالتهاب الرئوي في زامبيا",
    "Category:Deaths from pneumonia in Zimbabwe": "تصنيف:وفيات الالتهاب الرئوي في زيمبابوي",
}

data_2 = {}

to_test = [
    ("test_deaths_data_1", data_1),
    ("test_deaths_data_2", data_2),
]


@pytest.mark.parametrize("name,data", to_test)
@pytest.mark.dump
def test_dump_all(name: str, data: dict[str, str]) -> None:
    expected, diff_result = one_dump_test(data, resolve_arabic_category_label)
    dump_diff(diff_result, name)

    # same_data = {x: v for x, v in data.items() if x not in diff_result}
    # dump_diff(same_data, f"{name}_same")
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"



import functools
import re

from ...helps import logger

REGEX_WOMENS = re.compile(r"\b(womens|women)\b", re.I)
REGEX_THE = re.compile(r"\b(the)\b", re.I)


def fix_keys(category: str) -> str:
    original_category = category
    category = category.replace("'", "").lower()
    category = REGEX_THE.sub("", category)
    category = re.sub(r"\s+", " ", category)

    replacements = {
        "expatriates": "expatriate",
        "canadian football": "canadian-football",
    }

    for old, new in replacements.items():
        category = category.replace(old, new)

    category = REGEX_WOMENS.sub("female", category)
    logger.debug(f"fix_keys: {original_category} -> {category}")
    return category.strip()


def one_Keys_more_2(
    x,
    v,
    ar_nat_key="{ar_nat}",
    en_nat_key="{en_nat}",
    ar_job_key="{ar_job}",
    en_job_key="{en_job}",
    women_key="{women}",
    add_women=False,
) -> dict[str, str]:
    data = {}

    if not add_women:
        # Executed police officers / deaf triathletes
        data[f"{x} {en_job_key}"] = f"{ar_job_key} {v}"

        # writers blind
        data[f"{en_job_key} {x}"] = f"{ar_job_key} {v}"

        # greek blind
        data[f"{en_nat_key} {x}"] = f"{ar_nat_key} {v}"

        # Executed Albanian
        data[f"{x} {en_nat_key}"] = f"{ar_nat_key} {v}"

        # Executed Albanian police officers
        data[f"{x} {en_nat_key} {en_job_key}"] = f"{ar_job_key} {ar_nat_key} {v}"

        # greek writers blind
        data[f"{en_nat_key} {en_job_key} {x}"] = f"{ar_job_key} {ar_nat_key} {v}"

        # writers greek blind
        data[f"{en_job_key} {en_nat_key} {x}"] = f"{ar_job_key} {ar_nat_key} {v}"

        # Dutch political artists
        data[f"{en_nat_key} {x} {en_job_key}"] = f"{ar_job_key} {ar_nat_key} {v}"
    if add_women:
        # Executed Albanian women
        data[f"{x} {en_nat_key} {women_key}"] = f"{ar_nat_key} {v}"

        # female greek blind
        data[f"{women_key} {en_nat_key} {x}"] = f"{ar_nat_key} {v}"

        # female writers blind
        data[f"{women_key} {en_job_key} {x}"] = f"{ar_job_key} {v}"

        # Mauritanian female writers abolitionists
        data[f"{en_nat_key} {women_key} {en_job_key} {x}"] = f"{ar_job_key} {ar_nat_key} {v}"

        # female greek writers blind
        data[f"{women_key} {en_nat_key} {en_job_key} {x}"] = f"{ar_job_key} {ar_nat_key} {v}"

        # writers female greek blind
        data[f"{en_job_key} {women_key} {en_nat_key} {x}"] = f"{ar_job_key} {ar_nat_key} {v}"
        # female writers greek blind
        data[f"{women_key} {en_job_key} {en_nat_key} {x}"] = f"{ar_job_key} {ar_nat_key} {v}"

    return data


def nat_and_gender_keys(nat_job_key, key, gender_key, gender_label) -> dict[str, str]:
    data = {}

    # "Yemeni male muslims": "تصنيف:يمنيون مسلمون ذكور"
    # "Yemeni women's muslims": "تصنيف:يمنيات مسلمات"
    data[f"{nat_job_key} {gender_key} {key}"] = gender_label

    # "Yemeni muslims male": "تصنيف:يمنيون مسلمون ذكور"
    data[f"{nat_job_key} {key} {gender_key}"] = gender_label

    # "male Yemeni muslims": "تصنيف:يمنيون مسلمون ذكور"
    # "women's Yemeni muslims": "تصنيف:يمنيات مسلمات"
    data[f"{gender_key} {nat_job_key} {key}"] = gender_label

    return data


__all__ = [
    "nat_and_gender_keys",
]
